Class: Aws::GameLiftStreams::Types::AddStreamGroupLocationsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::AddStreamGroupLocationsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
A stream group to add the specified locations to.
-
#location_configurations ⇒ Array<Types::LocationConfiguration>
A set of one or more locations and the streaming capacity for each location.
Instance Attribute Details
#identifier ⇒ String
A stream group to add the specified locations to.
This value is an [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4`. Example ID: `sg-1AB2C3De4`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
49 50 51 52 53 54 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 49 class AddStreamGroupLocationsInput < Struct.new( :identifier, :location_configurations) SENSITIVE = [] include Aws::Structure end |
#location_configurations ⇒ Array<Types::LocationConfiguration>
A set of one or more locations and the streaming capacity for each location.
49 50 51 52 53 54 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 49 class AddStreamGroupLocationsInput < Struct.new( :identifier, :location_configurations) SENSITIVE = [] include Aws::Structure end |