Class: Aws::GameLiftStreams::Types::AssociateApplicationsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::AssociateApplicationsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_identifiers ⇒ Array<String>
A set of applications to associate with the stream group.
-
#identifier ⇒ String
A stream group to associate to the applications.
Instance Attribute Details
#application_identifiers ⇒ Array<String>
A set of applications to associate with the stream group.
This value is a set of either [Amazon Resource Names (ARN)] or IDs that uniquely identify application resources. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:application/9ZY8X7Wv6` or ID-`9ZY8X7Wv6`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
209 210 211 212 213 214 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 209 class AssociateApplicationsInput < Struct.new( :application_identifiers, :identifier) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
A stream group to associate to the applications.
This value is a [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/1AB2C3De4` or ID-`1AB2C3De4`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
209 210 211 212 213 214 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 209 class AssociateApplicationsInput < Struct.new( :application_identifiers, :identifier) SENSITIVE = [] include Aws::Structure end |