Class: Aws::GameLiftStreams::Types::AssociateApplicationsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::AssociateApplicationsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arns ⇒ Array<String>
A set of applications that are associated to the stream group.
-
#arn ⇒ String
A stream group that is associated to the applications.
Instance Attribute Details
#application_arns ⇒ Array<String>
A set of applications that are associated to the stream group.
This value is a set of either [Amazon Resource Names (ARN)] or IDs that uniquely identify application resources. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:application/9ZY8X7Wv6` or ID-`9ZY8X7Wv6`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
244 245 246 247 248 249 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 244 class AssociateApplicationsOutput < Struct.new( :application_arns, :arn) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
A stream group that is associated to the applications.
This value is a [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/1AB2C3De4` or ID-`1AB2C3De4`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
244 245 246 247 248 249 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 244 class AssociateApplicationsOutput < Struct.new( :application_arns, :arn) SENSITIVE = [] include Aws::Structure end |