Class: Aws::GameLiftStreams::Types::ConflictException
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::ConflictException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
The requested operation would cause a conflict with the current state of a service resource associated with the request. Resolve the conflict before retrying this request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Description of the error.
Instance Attribute Details
#message ⇒ String
Description of the error.
274 275 276 277 278 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 274 class ConflictException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |