Class: Aws::GameLiftStreams::Types::CreateApplicationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::CreateApplicationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_log_output_uri ⇒ String
An Amazon S3 URI to a bucket where you would like Amazon GameLift Streams to save application logs.
-
#application_log_paths ⇒ Array<String>
Locations of log files that your content generates during a stream session.
-
#application_source_uri ⇒ String
The location of the content that you want to stream.
-
#client_token ⇒ String
A unique identifier that represents a client request.
-
#description ⇒ String
A human-readable label for the application.
-
#executable_path ⇒ String
The path and file name of the executable file that launches the content for streaming.
-
#runtime_environment ⇒ Types::RuntimeEnvironment
Configuration settings that identify the operating system for an application resource.
-
#tags ⇒ Hash<String,String>
A list of labels to assign to the new application resource.
Instance Attribute Details
#application_log_output_uri ⇒ String
An Amazon S3 URI to a bucket where you would like Amazon GameLift Streams to save application logs. Required if you specify one or more ‘ApplicationLogPaths`.
<note markdown=“1”> The log bucket must have permissions that give Amazon GameLift Streams access to write the log files. For more information, see
- Application log bucket permission policy][1
-
in the *Amazon
GameLift Streams Developer Guide*.
</note>
384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 384 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#application_log_paths ⇒ Array<String>
Locations of log files that your content generates during a stream session. Enter path values that are relative to the ‘ApplicationSourceUri` location. You can specify up to 10 log paths. Amazon GameLift Streams uploads designated log files to the Amazon S3 bucket that you specify in `ApplicationLogOutputUri` at the end of a stream session. To retrieve stored log files, call
- GetStreamSession][1
-
and get the ‘LogFileLocationUri`.
[1]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_GetStreamSession.html
384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 384 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#application_source_uri ⇒ String
The location of the content that you want to stream. Enter an Amazon S3 URI to a bucket that contains your game or other application. The location can have a multi-level prefix structure, but it must include all the files needed to run the content. Amazon GameLift Streams copies everything under the specified location.
This value is immutable. To designate a different content location, create a new application.
<note markdown=“1”> The Amazon S3 bucket and the Amazon GameLift Streams application must be in the same Amazon Web Services Region.
</note>
384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 384 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique identifier that represents a client request. The request is idempotent, which ensures that an API request completes only once. When users send a request, Amazon GameLift Streams automatically populates this field.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 384 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A human-readable label for the application. You can update this value later.
384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 384 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#executable_path ⇒ String
The path and file name of the executable file that launches the content for streaming. Enter a path value that is relative to the location set in ‘ApplicationSourceUri`.
384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 384 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#runtime_environment ⇒ Types::RuntimeEnvironment
Configuration settings that identify the operating system for an application resource. This can also include a compatibility layer and other drivers.
A runtime environment can be one of the following:
-
For Linux applications
-
Ubuntu 22.04 LTS (‘Type=UBUNTU, Version=22_04_LTS`)
^
-
-
For Windows applications
-
Microsoft Windows Server 2022 Base (‘Type=WINDOWS, Version=2022`)
-
Proton 8.0-5 (‘Type=PROTON, Version=20241007`)
-
Proton 8.0-2c (‘Type=PROTON, Version=20230704`)
-
384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 384 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of labels to assign to the new application resource. Tags are developer-defined key-value pairs. Tagging Amazon Web Services resources is useful for resource management, access management and cost allocation. See [ Tagging Amazon Web Services Resources] in the *Amazon Web Services General Reference*. You can use
- TagResource][2
-
to add tags, [UntagResource] to remove tags, and
- ListTagsForResource][4
-
to view tags on existing resources.
[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html [2]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_TagResource.html [3]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_UntagResource.html [4]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_ListTagsForResource.html
384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 384 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |