Class: Aws::GameLiftStreams::Types::CreateApplicationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::CreateApplicationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_log_output_uri ⇒ String
An Amazon S3 URI to a bucket where you would like Amazon GameLift Streams to save application logs.
-
#application_log_paths ⇒ Array<String>
Locations of log files that your content generates during a stream session.
-
#application_source_uri ⇒ String
The original Amazon S3 location of uploaded stream content for the application.
-
#arn ⇒ String
An Amazon Resource Name (ARN) that’s assigned to an application resource and uniquely identifies it across all Amazon Web Services Regions.
-
#associated_stream_groups ⇒ Array<String>
A newly created application is not associated to any stream groups.
-
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
-
#description ⇒ String
A human-readable label for the application.
-
#executable_path ⇒ String
The path and file name of the executable file that launches the content for streaming.
-
#id ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the application resource.
-
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
-
#replication_statuses ⇒ Array<Types::ReplicationStatus>
A set of replication statuses for each location.
-
#runtime_environment ⇒ Types::RuntimeEnvironment
A set of configuration settings to run the application on a stream group.
-
#status ⇒ String
The current status of the application resource.
-
#status_reason ⇒ String
A short description of the status reason when the application is in ‘ERROR` status.
Instance Attribute Details
#application_log_output_uri ⇒ String
An Amazon S3 URI to a bucket where you would like Amazon GameLift Streams to save application logs. Use the following format for the URI: ‘s3://[bucket name]/`. Required if you specify one or more `LogPaths`.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#application_log_paths ⇒ Array<String>
Locations of log files that your content generates during a stream session. Amazon GameLift Streams uploads log files to the Amazon S3 bucket that you specify in ‘ApplicationLogOutputUri` at the end of a stream session. To retrieve stored log files, call GetStreamSession and get the `LogFileLocationUri`.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#application_source_uri ⇒ String
The original Amazon S3 location of uploaded stream content for the application.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
An Amazon Resource Name (ARN) that’s assigned to an application resource and uniquely identifies it across all Amazon Web Services Regions. Format is ‘arn:aws:gameliftstreams:[AWS Region]:[AWS account]:application/[resource ID]`.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#associated_stream_groups ⇒ Array<String>
A newly created application is not associated to any stream groups. This value is empty.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
A timestamp that indicates when this resource was created. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A human-readable label for the application. You can edit this value.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#executable_path ⇒ String
The path and file name of the executable file that launches the content for streaming.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the application resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:application/9ZY8X7Wv6` or ID-`9ZY8X7Wv6`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#replication_statuses ⇒ Array<Types::ReplicationStatus>
A set of replication statuses for each location.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#runtime_environment ⇒ Types::RuntimeEnvironment
A set of configuration settings to run the application on a stream group. This configures the operating system, and can include compatibility layers and other drivers.
A runtime environment can be one of the following:
-
For Linux applications
-
Ubuntu 22.04 LTS(‘Type=UBUNTU, Version=22_04_LTS`)
^
-
-
For Windows applications
-
Microsoft Windows Server 2022 Base (‘Type=WINDOWS, Version=2022`)
-
Proton 8.0-5 (‘Type=PROTON, Version=20241007`)
-
Proton 8.0-2c (‘Type=PROTON, Version=20230704`)
-
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the application resource. Possible statuses include the following:
-
‘INITIALIZED`: Amazon GameLift Streams has received the request and is initiating the work flow to create an application.
-
‘PROCESSING`: The create application work flow is in process. Amazon GameLift Streams is copying the content and caching for future deployment in a stream group.
-
‘READY`: The application is ready to deploy in a stream group.
-
‘ERROR`: An error occurred when setting up the application. See `StatusReason` for more information.
-
‘DELETING`: Amazon GameLift Streams is in the process of deleting the application.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
A short description of the status reason when the application is in ‘ERROR` status.
499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 499 class CreateApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |