Class: Aws::GameLiftStreams::Types::CreateStreamSessionConnectionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:signal_request]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique identifier that represents a client request. The request is idempotent, which ensures that an API request completes only once. When users send a request, Amazon GameLift Streams automatically populates this field.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1188
1189
1190
1191
1192
1193
1194
1195
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1188

class CreateStreamSessionConnectionInput < Struct.new(
  :client_token,
  :identifier,
  :stream_session_identifier,
  :signal_request)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#identifierString

Amazon Resource Name (ARN)][1

or ID that uniquely identifies the

stream group resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4`. Example ID: `sg-1AB2C3De4`.

The stream group that you want to run this stream session with. The stream group must be in ‘ACTIVE` status.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


1188
1189
1190
1191
1192
1193
1194
1195
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1188

class CreateStreamSessionConnectionInput < Struct.new(
  :client_token,
  :identifier,
  :stream_session_identifier,
  :signal_request)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#signal_requestString

A WebRTC ICE offer string to use when initializing a WebRTC connection. The offer is a very long JSON string. Provide the string as a text value in quotes. The offer must be newly generated, not the same offer provided to ‘StartStreamSession`.

Returns:

  • (String)


1188
1189
1190
1191
1192
1193
1194
1195
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1188

class CreateStreamSessionConnectionInput < Struct.new(
  :client_token,
  :identifier,
  :stream_session_identifier,
  :signal_request)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#stream_session_identifierString

Amazon Resource Name (ARN)][1

or ID that uniquely identifies the

stream session resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:streamsession/sg-1AB2C3De4/ABC123def4567`. Example ID: `ABC123def4567`.

The stream session must be in ‘PENDING_CLIENT_RECONNECTION` or `ACTIVE` status.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


1188
1189
1190
1191
1192
1193
1194
1195
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1188

class CreateStreamSessionConnectionInput < Struct.new(
  :client_token,
  :identifier,
  :stream_session_identifier,
  :signal_request)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end