Class: Aws::GameLiftStreams::Types::CreateStreamUrlInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:role_arn]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_environment_variablesHash<String,String>

A set of options that you can use to control the stream session runtime environment, expressed as a set of key-value pairs. You can use this to configure the application or stream session details. You can also provide custom environment variables that Amazon GameLift Streams passes to your game client.

If you want to debug your application with environment variables, we recommend that you do so in a local environment outside of Amazon GameLift Streams. For more information, refer to the Compatibility Guidance in the troubleshooting section of the Developer Guide.

AdditionalEnvironmentVariables and AdditionalLaunchArgs have similar purposes. AdditionalEnvironmentVariables passes data using environment variables; while AdditionalLaunchArgs passes data using command-line arguments.

Returns:

  • (Hash<String,String>)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#additional_launch_argsArray<String>

A list of CLI arguments that are sent to the streaming server when a stream session launches. You can use this to configure the application or stream session details. You can also provide custom arguments that Amazon GameLift Streams passes to your game client.

AdditionalEnvironmentVariables and AdditionalLaunchArgs have similar purposes. AdditionalEnvironmentVariables passes data using environment variables; while AdditionalLaunchArgs passes data using command-line arguments.

Returns:

  • (Array<String>)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#application_identifierString

An Amazon Resource Name (ARN) or ID that uniquely identifies the application resource. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6. Example ID: a-9ZY8X7Wv6.

This application must be associated with the stream group.

Returns:

  • (String)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure this request is idempotent. If you retry a request with the same ClientToken, Amazon GameLift Streams returns the original response without performing the operation again.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#descriptionString

A descriptive label for the stream URL.

Returns:

  • (String)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#display_configurationTypes::DisplayConfiguration

The display settings, such as resolution, for stream sessions started from this stream URL.



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#identifierString

An Amazon Resource Name (ARN) or ID that uniquely identifies the stream group resource. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4. Example ID: sg-1AB2C3De4.

The stream session runs in this stream group.

Returns:

  • (String)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#locationsArray<String>

A list of locations, in order of preference, where Amazon GameLift Streams can place the stream session. Specify each location by its Amazon Web Services Region code, for example us-east-1. For a complete list of locations that Amazon GameLift Streams supports, refer to Regions, quotas, and limitations in the Amazon GameLift Streams Developer Guide.

Returns:

  • (Array<String>)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#protocolString

The data transport protocol for the stream session. Amazon GameLift Streams supports WebRTC.

Returns:

  • (String)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role that Amazon GameLift Streams assumes during stream sessions started from this stream URL. For more information, see Provide AWS credentials to your streaming application in the Amazon GameLift Streams Developer Guide.

Returns:

  • (String)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#session_length_secondsInteger

The maximum length of time, in seconds, that a stream session started from this stream URL can run. Valid values are 1-86400 seconds (1 second to 24 hours). The default is 43200 seconds (12 hours).

Returns:

  • (Integer)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#url_expires_after_minutesInteger

The number of minutes after creation that the stream URL remains valid. After this period, the status of the stream URL changes to EXPIRED and it can no longer start stream sessions. The minimum is 1 minute. For the maximum, see Regions, quotas, and limitations in the Amazon GameLift Streams Developer Guide.

Returns:

  • (Integer)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end

#usage_limitInteger

The maximum number of times the stream URL can start a stream session. Each successful use reduces the remaining uses by one. The minimum is 1, and the default is 1. For the maximum, see Regions, quotas, and limitations in the Amazon GameLift Streams Developer Guide.

Returns:

  • (Integer)


1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1476

class CreateStreamUrlInput < Struct.new(
  :identifier,
  :application_identifier,
  :protocol,
  :url_expires_after_minutes,
  :usage_limit,
  :description,
  :locations,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :role_arn,
  :display_configuration,
  :client_token)
  SENSITIVE = [:role_arn]
  include Aws::Structure
end