Class: Aws::GameLiftStreams::Types::DisassociateApplicationsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::DisassociateApplicationsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arns ⇒ Array<String>
A set of applications that are disassociated from this stream group.
-
#arn ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource.
Instance Attribute Details
#application_arns ⇒ Array<String>
A set of applications that are disassociated from this stream group.
This value is a set of either [Amazon Resource Names (ARN)] or IDs that uniquely identify application resources. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:application/a-9ZY8X7Wv6` or ID-`a-9ZY8X7Wv6`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1063 class DisassociateApplicationsOutput < Struct.new( :application_arns, :arn) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/sg-1AB2C3De4` or ID-`sg-1AB2C3De4`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1063 class DisassociateApplicationsOutput < Struct.new( :application_arns, :arn) SENSITIVE = [] include Aws::Structure end |