Class: Aws::GameLiftStreams::Types::ExportFilesMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::ExportFilesMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Provides details about the stream session’s exported files.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#output_uri ⇒ String
The S3 bucket URI where Amazon GameLift Streams uploaded the set of compressed exported files for a stream session.
-
#status ⇒ String
The result of the ExportStreamSessionFiles operation.
-
#status_reason ⇒ String
A short description of the reason the export is in ‘FAILED` status.
Instance Attribute Details
#output_uri ⇒ String
The S3 bucket URI where Amazon GameLift Streams uploaded the set of compressed exported files for a stream session. Amazon GameLift Streams generates a ZIP file name based on the stream session metadata. Alternatively, you can provide a custom file name with a ‘.zip` file extension.
Example 1: If you provide an S3 URI called ‘s3://MyBucket/MyGame_Session1.zip`, then Amazon GameLift Streams will save the files at that location.
Example 2: If you provide an S3 URI called ‘s3://MyBucket/MyGameSessions_ExportedFiles/`, then Amazon GameLift Streams will save the files at `s3://MyBucket/MyGameSessions_ExportedFiles/YYYYMMDD-HHMMSS-appId-sg-Id-sessionId.zip` or another similar name.
1098 1099 1100 1101 1102 1103 1104 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1098 class ExportFilesMetadata < Struct.new( :output_uri, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The result of the ExportStreamSessionFiles operation.
1098 1099 1100 1101 1102 1103 1104 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1098 class ExportFilesMetadata < Struct.new( :output_uri, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
A short description of the reason the export is in ‘FAILED` status.
1098 1099 1100 1101 1102 1103 1104 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1098 class ExportFilesMetadata < Struct.new( :output_uri, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |