Class: Aws::GameLiftStreams::Types::ExportStreamSessionFilesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identifierString

An Amazon Resource Name (ARN) or ID that uniquely identifies the stream group resource. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4. Example ID: sg-1AB2C3De4.

Returns:

  • (String)


1553
1554
1555
1556
1557
1558
1559
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1553

class ExportStreamSessionFilesInput < Struct.new(
  :identifier,
  :stream_session_identifier,
  :output_uri)
  SENSITIVE = []
  include Aws::Structure
end

#output_uriString

The S3 bucket URI where Amazon GameLift Streams uploads the set of compressed exported files for this stream session. Amazon GameLift Streams generates a ZIP file name based on the stream session metadata. Alternatively, you can provide a custom file name with a .zip file extension.

Example 1: If you provide an S3 URI called s3://amzn-s3-demo-destination-bucket/MyGame_Session1.zip, then Amazon GameLift Streams will save the files at that location.

Example 2: If you provide an S3 URI called s3://amzn-s3-demo-destination-bucket/MyGameSessions_ExportedFiles/, then Amazon GameLift Streams will save the files at s3://amzn-s3-demo-destination-bucket/MyGameSessions_ExportedFiles/YYYYMMDD-HHMMSS-appId-sg-Id-sessionId.zip or another similar name.

Returns:

  • (String)


1553
1554
1555
1556
1557
1558
1559
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1553

class ExportStreamSessionFilesInput < Struct.new(
  :identifier,
  :stream_session_identifier,
  :output_uri)
  SENSITIVE = []
  include Aws::Structure
end

#stream_session_identifierString

An Amazon Resource Name (ARN) or ID that uniquely identifies the stream session resource. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:streamsession/sg-1AB2C3De4/ABC123def4567. Example ID: ABC123def4567.

Returns:

  • (String)


1553
1554
1555
1556
1557
1558
1559
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1553

class ExportStreamSessionFilesInput < Struct.new(
  :identifier,
  :stream_session_identifier,
  :output_uri)
  SENSITIVE = []
  include Aws::Structure
end