Class: Aws::GameLiftStreams::Types::GetApplicationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::GetApplicationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_log_output_uri ⇒ String
An Amazon S3 URI to a bucket where you would like Amazon GameLift Streams to save application logs.
-
#application_log_paths ⇒ Array<String>
Locations of log files that your content generates during a stream session.
-
#application_source_uri ⇒ String
The original Amazon S3 location of uploaded stream content for the application.
-
#arn ⇒ String
The [Amazon Resource Name (ARN)][1] that's assigned to an application resource and uniquely identifies it across all Amazon Web Services Regions.
-
#associated_stream_groups ⇒ Array<String>
A set of stream groups that this application is associated with.
-
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
-
#description ⇒ String
A human-readable label for the application.
-
#executable_path ⇒ String
The relative path and file name of the executable file that launches the content for streaming.
-
#id ⇒ String
A unique ID value that is assigned to the resource when it's created.
-
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
-
#replication_statuses ⇒ Array<Types::ReplicationStatus>
A set of replication statuses for each location.
-
#runtime_environment ⇒ Types::RuntimeEnvironment
Configuration settings that identify the operating system for an application resource.
-
#status ⇒ String
The current status of the application resource.
-
#status_reason ⇒ String
A short description of the status reason when the application is in
ERRORstatus.
Instance Attribute Details
#application_log_output_uri ⇒ String
An Amazon S3 URI to a bucket where you would like Amazon GameLift
Streams to save application logs. Required if you specify one or
more ApplicationLogPaths.
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#application_log_paths ⇒ Array<String>
Locations of log files that your content generates during a stream
session. Amazon GameLift Streams uploads log files to the Amazon S3
bucket that you specify in ApplicationLogOutputUri at the end of a
stream session. To retrieve stored log files, call
GetStreamSession and get the LogFileLocationUri.
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#application_source_uri ⇒ String
The original Amazon S3 location of uploaded stream content for the application.
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) that's assigned to an
application resource and uniquely identifies it across all Amazon
Web Services Regions. Format is arn:aws:gameliftstreams:[AWS Region]:[AWS account]:application/[resource ID].
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#associated_stream_groups ⇒ Array<String>
A set of stream groups that this application is associated with. You can use any of these stream groups to stream your application.
This value is a set of Amazon Resource Names (ARNs) that
uniquely identify stream group resources. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4.
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
Timestamps are expressed using in ISO8601 format, such as:
2022-12-27T22:29:40+00:00 (UTC).
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A human-readable label for the application. You can edit this value.
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#executable_path ⇒ String
The relative path and file name of the executable file that launches the content for streaming.
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique ID value that is assigned to the resource when it's
created. Format example: a-9ZY8X7Wv6.
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
Timestamps are expressed using in ISO8601 format, such as:
2022-12-27T22:29:40+00:00 (UTC).
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#replication_statuses ⇒ Array<Types::ReplicationStatus>
A set of replication statuses for each location.
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#runtime_environment ⇒ Types::RuntimeEnvironment
Configuration settings that identify the operating system for an application resource. This can also include a compatibility layer and other drivers.
A runtime environment can be one of the following:
-
For Linux applications
-
Ubuntu 22.04 LTS (
Type=UBUNTU, Version=22_04_LTS)
^
-
For Windows applications
-
Microsoft Windows Server 2022 Base (
Type=WINDOWS, Version=2022) -
Proton 10.0-4 (
Type=PROTON, Version=20260204) -
Proton 9.0-2 (
Type=PROTON, Version=20250516) -
Proton 8.0-5 (
Type=PROTON, Version=20241007) -
Proton 8.0-2c (
Type=PROTON, Version=20230704)
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the application resource. Possible statuses include the following:
-
INITIALIZED: Amazon GameLift Streams has received the request and is initiating the work flow to create an application. -
PROCESSING: The create application work flow is in process. Amazon GameLift Streams is copying the content and caching for future deployment in a stream group. -
READY: The application is ready to deploy in a stream group. -
ERROR: An error occurred when setting up the application. SeeStatusReasonfor more information. -
DELETING: Amazon GameLift Streams is in the process of deleting the application.
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
A short description of the status reason when the application is in
ERROR status.
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2074 class GetApplicationOutput < Struct.new( :arn, :description, :runtime_environment, :executable_path, :application_log_paths, :application_log_output_uri, :application_source_uri, :id, :status, :status_reason, :replication_statuses, :created_at, :last_updated_at, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |