Class: Aws::GameLiftStreams::Types::GetStreamSessionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::GetStreamSessionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:signal_request, :signal_response]
Instance Attribute Summary collapse
-
#additional_environment_variables ⇒ Hash<String,String>
A set of options that you can use to control the stream session runtime environment, expressed as a set of key-value pairs.
-
#additional_launch_args ⇒ Array<String>
A list of CLI arguments that are sent to the streaming server when a stream session launches.
-
#application_arn ⇒ String
The application streaming in this session.
-
#arn ⇒ String
The [Amazon Resource Name (ARN)] that’s assigned to a stream session resource.
-
#connection_timeout_seconds ⇒ Integer
The length of time that Amazon GameLift Streams should wait for a client to connect or reconnect to the stream session.
-
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
-
#description ⇒ String
A human-readable label for the stream session.
-
#export_files_metadata ⇒ Types::ExportFilesMetadata
Provides details about the stream session’s exported files.
-
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
-
#location ⇒ String
The location where Amazon GameLift Streams hosts and streams your application.
-
#log_file_location_uri ⇒ String
Access location for log files that your content generates during a stream session.
-
#performance_stats_configuration ⇒ Types::PerformanceStatsConfiguration
The performance stats configuration for the stream session.
-
#protocol ⇒ String
The data transfer protocol in use with the stream session.
-
#session_length_seconds ⇒ Integer
The maximum duration of a session.
-
#signal_request ⇒ String
The WebRTC ICE offer string that a client generates to initiate a connection to the stream session.
-
#signal_response ⇒ String
The WebRTC answer string that the stream server generates in response to the ‘SignalRequest`.
-
#status ⇒ String
The current status of the stream session.
-
#status_reason ⇒ String
A short description of the reason the stream session is in ‘ERROR` status or `TERMINATED` status.
-
#stream_group_id ⇒ String
The unique identifier for the Amazon GameLift Streams stream group that is hosting the stream session.
-
#user_id ⇒ String
An opaque, unique identifier for an end-user, defined by the developer.
-
#web_sdk_protocol_url ⇒ String
The URL of an S3 bucket that stores Amazon GameLift Streams WebSDK files.
Instance Attribute Details
#additional_environment_variables ⇒ Hash<String,String>
A set of options that you can use to control the stream session runtime environment, expressed as a set of key-value pairs. You can use this to configure the application or stream session details. You can also provide custom environment variables that Amazon GameLift Streams passes to your game client.
<note markdown=“1”> If you want to debug your application with environment variables, we recommend that you do so in a local environment outside of Amazon GameLift Streams. For more information, refer to the Compatibility Guidance in the troubleshooting section of the Developer Guide.
</note>
‘AdditionalEnvironmentVariables` and `AdditionalLaunchArgs` have similar purposes. `AdditionalEnvironmentVariables` passes data using environment variables; while `AdditionalLaunchArgs` passes data using command-line arguments.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#additional_launch_args ⇒ Array<String>
A list of CLI arguments that are sent to the streaming server when a stream session launches. You can use this to configure the application or stream session details. You can also provide custom arguments that Amazon GameLift Streams passes to your game client.
‘AdditionalEnvironmentVariables` and `AdditionalLaunchArgs` have similar purposes. `AdditionalEnvironmentVariables` passes data using environment variables; while `AdditionalLaunchArgs` passes data using command-line arguments.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#application_arn ⇒ String
The application streaming in this session.
This value is an [Amazon Resource Name (ARN)] that uniquely identifies the application resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#arn ⇒ String
The [Amazon Resource Name (ARN)] that’s assigned to a stream session resource. When combined with the stream group resource ID, this value uniquely identifies the stream session across all Amazon Web Services Regions. Format is ‘arn:aws:gameliftstreams:[AWS Region]:[AWS account]:streamsession/[stream group resource ID]/[stream session resource ID]`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#connection_timeout_seconds ⇒ Integer
The length of time that Amazon GameLift Streams should wait for a client to connect or reconnect to the stream session. This time span starts when the stream session reaches ‘ACTIVE` or `PENDING_CLIENT_RECONNECTION` state. If no client connects (or reconnects) before the timeout, Amazon GameLift Streams terminates the stream session.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#created_at ⇒ Time
A timestamp that indicates when this resource was created. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#description ⇒ String
A human-readable label for the stream session. You can update this value at any time.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#export_files_metadata ⇒ Types::ExportFilesMetadata
Provides details about the stream session’s exported files.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#location ⇒ String
The location where Amazon GameLift Streams hosts and streams your application. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, refer to [Regions, quotas, and limitations] in the *Amazon GameLift Streams Developer Guide*.
[1]: docs.aws.amazon.com/gameliftstreams/latest/developerguide/regions-quotas.html
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#log_file_location_uri ⇒ String
Access location for log files that your content generates during a stream session. These log files are uploaded to cloud storage location at the end of a stream session. The Amazon GameLift Streams application resource defines which log files to upload.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#performance_stats_configuration ⇒ Types::PerformanceStatsConfiguration
The performance stats configuration for the stream session
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#protocol ⇒ String
The data transfer protocol in use with the stream session.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#session_length_seconds ⇒ Integer
The maximum duration of a session. Amazon GameLift Streams will automatically terminate a session after this amount of time has elapsed, regardless of any existing client connections.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#signal_request ⇒ String
The WebRTC ICE offer string that a client generates to initiate a connection to the stream session.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#signal_response ⇒ String
The WebRTC answer string that the stream server generates in response to the ‘SignalRequest`.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#status ⇒ String
The current status of the stream session. A stream session is ready for a client to connect when in ‘ACTIVE` status.
-
‘ACTIVATING`: The stream session is starting and preparing to stream.
-
‘ACTIVE`: The stream session is ready and waiting for a client connection. A client has `ConnectionTimeoutSeconds` (specified in `StartStreamSession`) from when the session reaches `ACTIVE` state to establish a connection. If no client connects within this timeframe, the session automatically terminates.
-
‘CONNECTED`: The stream session has a connected client. A session will automatically terminate if there is no user input for 60 minutes, or if the maximum length of a session specified by `SessionLengthSeconds` in `StartStreamSession` is exceeded.
-
‘ERROR`: The stream session failed to activate. See `StatusReason` (returned by `GetStreamSession` and `StartStreamSession`) for more information.
-
‘PENDING_CLIENT_RECONNECTION`: A client has recently disconnected and the stream session is waiting for the client to reconnect. A client has `ConnectionTimeoutSeconds` (specified in `StartStreamSession`) from when the session reaches `PENDING_CLIENT_RECONNECTION` state to re-establish a connection. If no client connects within this timeframe, the session automatically terminates.
-
‘RECONNECTING`: A client has initiated a reconnect to a session that was in `PENDING_CLIENT_RECONNECTION` state.
-
‘TERMINATING`: The stream session is ending.
-
‘TERMINATED`: The stream session has ended.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#status_reason ⇒ String
A short description of the reason the stream session is in ‘ERROR` status or `TERMINATED` status.
‘ERROR` status reasons:
-
‘applicationLogS3DestinationError`: Could not write the application log to the Amazon S3 bucket that is configured for the streaming application. Make sure the bucket still exists.
-
‘internalError`: An internal service error occurred. Start a new stream session to continue streaming.
-
‘invalidSignalRequest`: The WebRTC signal request that was sent is not valid. When starting or reconnecting to a stream session, use `generateSignalRequest` in the Amazon GameLift Streams Web SDK to generate a new signal request.
-
‘placementTimeout`: Amazon GameLift Streams could not find available stream capacity to start a stream session. Increase the stream capacity in the stream group or wait until capacity becomes available.
‘TERMINATED` status reasons:
-
‘apiTerminated`: The stream session was terminated by an API call to [TerminateStreamSession].
-
‘applicationExit`: The streaming application exited or crashed. The stream session was terminated because the application is no longer running.
-
‘connectionTimeout`: The stream session was terminated because the client failed to connect within the connection timeout period specified by `ConnectionTimeoutSeconds`.
-
‘maxSessionLengthTimeout`: The stream session was terminated because it exceeded the maximum session length timeout period specified by `SessionLengthSeconds`.
-
‘reconnectionTimeout`: The stream session was terminated because the client failed to reconnect within the reconnection timeout period specified by `ConnectionTimeoutSeconds` after losing connection.
[1]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_TerminateStreamSession.html
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#stream_group_id ⇒ String
The unique identifier for the Amazon GameLift Streams stream group that is hosting the stream session. Format example: ‘sg-1AB2C3De4`.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#user_id ⇒ String
An opaque, unique identifier for an end-user, defined by the developer.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#web_sdk_protocol_url ⇒ String
The URL of an S3 bucket that stores Amazon GameLift Streams WebSDK files. The URL is used to establish connection with the client.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2221 class GetStreamSessionOutput < Struct.new( :arn, :description, :stream_group_id, :user_id, :status, :status_reason, :protocol, :location, :signal_request, :signal_response, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :log_file_location_uri, :web_sdk_protocol_url, :last_updated_at, :created_at, :application_arn, :export_files_metadata) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |