Class: Aws::GameLiftStreams::Types::LocationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::LocationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Configuration settings that define a stream group’s stream capacity for a location. When configuring a location for the first time, you must specify a numeric value for at least one of the two capacity types. To update the capacity for an existing stream group, call [UpdateStreamGroup]. To add a new location and specify its capacity, call [AddStreamGroupLocations].
[1]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_UpdateStreamGroup.html [2]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_AddStreamGroupLocations.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#always_on_capacity ⇒ Integer
The streaming capacity that is allocated and ready to handle stream requests without delay.
-
#location_name ⇒ String
A location’s name.
-
#on_demand_capacity ⇒ Integer
The streaming capacity that Amazon GameLift Streams can allocate in response to stream requests, and then de-allocate when the session has terminated.
Instance Attribute Details
#always_on_capacity ⇒ Integer
The streaming capacity that is allocated and ready to handle stream requests without delay. You pay for this capacity whether it’s in use or not. Best for quickest time from streaming request to streaming session.
2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2048 class LocationConfiguration < Struct.new( :always_on_capacity, :location_name, :on_demand_capacity) SENSITIVE = [] include Aws::Structure end |
#location_name ⇒ String
A location’s name. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, refer to [Regions and quotas] in the *Amazon GameLift Streams Developer Guide*.
[1]: docs.aws.amazon.com/gameliftstreams/latest/developerguide/regions-quotas.html
2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2048 class LocationConfiguration < Struct.new( :always_on_capacity, :location_name, :on_demand_capacity) SENSITIVE = [] include Aws::Structure end |
#on_demand_capacity ⇒ Integer
The streaming capacity that Amazon GameLift Streams can allocate in response to stream requests, and then de-allocate when the session has terminated. This offers a cost control measure at the expense of a greater startup time (typically under 5 minutes).
2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2048 class LocationConfiguration < Struct.new( :always_on_capacity, :location_name, :on_demand_capacity) SENSITIVE = [] include Aws::Structure end |