Class: Aws::GameLiftStreams::Types::RemoveStreamGroupLocationsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identifierString

A stream group to remove the specified locations from.

This value is an [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4`. Example ID: `sg-1AB2C3De4`.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


2219
2220
2221
2222
2223
2224
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2219

class RemoveStreamGroupLocationsInput < Struct.new(
  :identifier,
  :locations)
  SENSITIVE = []
  include Aws::Structure
end

#locationsArray<String>

A set of locations to remove this stream group.

A set of location names. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, refer to

Regions, quotas, and limitations][1

in the *Amazon GameLift

Streams Developer Guide*.

[1]: docs.aws.amazon.com/gameliftstreams/latest/developerguide/regions-quotas.html

Returns:

  • (Array<String>)


2219
2220
2221
2222
2223
2224
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2219

class RemoveStreamGroupLocationsInput < Struct.new(
  :identifier,
  :locations)
  SENSITIVE = []
  include Aws::Structure
end