Class: Aws::GameLiftStreams::Types::RuntimeEnvironment
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::RuntimeEnvironment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Configuration settings that identify the operating system for an application resource. This can also include a compatibility layer and other drivers.
A runtime environment can be one of the following:
-
For Linux applications
-
Ubuntu 22.04 LTS (‘Type=UBUNTU, Version=22_04_LTS`)
^
-
-
For Windows applications
-
Microsoft Windows Server 2022 Base (‘Type=WINDOWS, Version=2022`)
-
Proton 10.0-4 (‘Type=PROTON, Version=20260204`)
-
Proton 9.0-2 (‘Type=PROTON, Version=20250516`)
-
Proton 8.0-5 (‘Type=PROTON, Version=20241007`)
-
Proton 8.0-2c (‘Type=PROTON, Version=20230704`)
-
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#type ⇒ String
The operating system and other drivers.
-
#version ⇒ String
Versioned container environment for the application operating system.
Instance Attribute Details
#type ⇒ String
The operating system and other drivers. For Proton, this also includes the Proton compatibility layer.
2851 2852 2853 2854 2855 2856 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2851 class RuntimeEnvironment < Struct.new( :type, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
Versioned container environment for the application operating system.
2851 2852 2853 2854 2855 2856 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2851 class RuntimeEnvironment < Struct.new( :type, :version) SENSITIVE = [] include Aws::Structure end |