Class: Aws::GameLiftStreams::Types::ShaderCacheSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Describes a shader cache associated with an Amazon GameLift Streams application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_arnString

An Amazon Resource Name (ARN) that uniquely identifies the application resource. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6.

Returns:

  • (String)


3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856

class ShaderCacheSummary < Struct.new(
  :identifier,
  :application_arn,
  :status,
  :last_updated_at,
  :storage_bytes,
  :associated_stream_groups)
  SENSITIVE = []
  include Aws::Structure
end

#associated_stream_groupsArray<String>

The stream groups compatible with this shader cache. Compatibility is based on GPU type and GPU driver version. For more information on shader cache compatibility, see Shader caches in the Amazon GameLift Streams Developer Guide.

This value is a set of Amazon Resource Names (ARNs) that uniquely identify stream group resources. Example ARN: arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4.

Returns:

  • (Array<String>)


3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856

class ShaderCacheSummary < Struct.new(
  :identifier,
  :application_arn,
  :status,
  :last_updated_at,
  :storage_bytes,
  :associated_stream_groups)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

A unique identifier for the shader cache, formatted as a 32-character hexadecimal string. Format is 1271e693c50b940e228582f1ccdd4e27.

Returns:

  • (String)


3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856

class ShaderCacheSummary < Struct.new(
  :identifier,
  :application_arn,
  :status,
  :last_updated_at,
  :storage_bytes,
  :associated_stream_groups)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

A timestamp that indicates when this resource was last updated. Timestamps are expressed using in ISO8601 format, such as: 2022-12-27T22:29:40+00:00 (UTC).

Returns:

  • (Time)


3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856

class ShaderCacheSummary < Struct.new(
  :identifier,
  :application_arn,
  :status,
  :last_updated_at,
  :storage_bytes,
  :associated_stream_groups)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the shader cache. Possible statuses include the following:

  • INITIALIZED: Amazon GameLift Streams received the request and is preparing the shader cache.

  • PROCESSING: Amazon GameLift Streams is replicating the shader cache to the streaming locations in the associated stream groups.

  • READY: The shader cache is replicated and available for use in stream sessions.

  • DELETING: Amazon GameLift Streams is deleting the shader cache.

  • ERROR: An error occurred during shader cache processing. Create a new shader cache to try again.

Returns:

  • (String)


3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856

class ShaderCacheSummary < Struct.new(
  :identifier,
  :application_arn,
  :status,
  :last_updated_at,
  :storage_bytes,
  :associated_stream_groups)
  SENSITIVE = []
  include Aws::Structure
end

#storage_bytesInteger

The total storage used by all compiled shader files in this shader cache, in bytes.

Returns:

  • (Integer)


3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856

class ShaderCacheSummary < Struct.new(
  :identifier,
  :application_arn,
  :status,
  :last_updated_at,
  :storage_bytes,
  :associated_stream_groups)
  SENSITIVE = []
  include Aws::Structure
end