Class: Aws::GameLiftStreams::Types::StartStreamSessionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::StartStreamSessionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:signal_request, :role_arn]
Instance Attribute Summary collapse
-
#additional_environment_variables ⇒ Hash<String,String>
A set of options that you can use to control the stream session runtime environment, expressed as a set of key-value pairs.
-
#additional_launch_args ⇒ Array<String>
A list of CLI arguments that are sent to the streaming server when a stream session launches.
-
#application_identifier ⇒ String
An [Amazon Resource Name (ARN)][1] or ID that uniquely identifies the application resource.
-
#client_token ⇒ String
A unique identifier that represents a client request.
-
#connection_timeout_seconds ⇒ Integer
Length of time (in seconds) that Amazon GameLift Streams should wait for a client to connect or reconnect to the stream session.
-
#description ⇒ String
A human-readable label for the stream session.
-
#identifier ⇒ String
The stream group to run this stream session with.
-
#locations ⇒ Array<String>
A list of locations, in order of priority, where you want Amazon GameLift Streams to start a stream from.
-
#performance_stats_configuration ⇒ Types::PerformanceStatsConfiguration
Configuration settings for sharing the stream session's performance stats with the client.
-
#protocol ⇒ String
The data transport protocol to use for the stream session.
-
#role_arn ⇒ String
The ARN of an AWS Identity and Access Management (IAM) role that Amazon GameLift Streams assumes on your behalf during the stream session.
-
#session_length_seconds ⇒ Integer
The maximum duration of a session.
-
#signal_request ⇒ String
A WebRTC ICE offer string to use when initializing a WebRTC connection.
-
#user_id ⇒ String
An opaque, unique identifier for an end-user, defined by the developer.
Instance Attribute Details
#additional_environment_variables ⇒ Hash<String,String>
A set of options that you can use to control the stream session runtime environment, expressed as a set of key-value pairs. You can use this to configure the application or stream session details. You can also provide custom environment variables that Amazon GameLift Streams passes to your game client.
AdditionalEnvironmentVariables and AdditionalLaunchArgs have
similar purposes. AdditionalEnvironmentVariables passes data using
environment variables; while AdditionalLaunchArgs passes data
using command-line arguments.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#additional_launch_args ⇒ Array<String>
A list of CLI arguments that are sent to the streaming server when a stream session launches. You can use this to configure the application or stream session details. You can also provide custom arguments that Amazon GameLift Streams passes to your game client.
AdditionalEnvironmentVariables and AdditionalLaunchArgs have
similar purposes. AdditionalEnvironmentVariables passes data using
environment variables; while AdditionalLaunchArgs passes data
using command-line arguments.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#application_identifier ⇒ String
An Amazon Resource Name (ARN) or ID that uniquely identifies
the application resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6.
Example ID: a-9ZY8X7Wv6.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#client_token ⇒ String
A unique identifier that represents a client request. The request is idempotent, which ensures that an API request completes only once. When users send a request, Amazon GameLift Streams automatically populates this field.
A suitable default value is auto-generated. You should normally not need to pass this option.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#connection_timeout_seconds ⇒ Integer
Length of time (in seconds) that Amazon GameLift Streams should wait
for a client to connect or reconnect to the stream session. Applies
to both connection and reconnection scenarios. This time span starts
when the stream session reaches ACTIVE state. If no client
connects before the timeout, Amazon GameLift Streams terminates the
stream session. Default value is 120.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#description ⇒ String
A human-readable label for the stream session. You can update this value later.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#identifier ⇒ String
The stream group to run this stream session with.
This value is an Amazon Resource Name (ARN) or ID that uniquely
identifies the stream group resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4.
Example ID: sg-1AB2C3De4.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#locations ⇒ Array<String>
A list of locations, in order of priority, where you want Amazon
GameLift Streams to start a stream from. For example, us-east-1.
Amazon GameLift Streams selects the location with the next available
capacity to start a single stream session in. If this value is
empty, Amazon GameLift Streams attempts to start a stream session in
the primary location.
For a complete list of locations that Amazon GameLift Streams supports, refer to Regions, quotas, and limitations in the Amazon GameLift Streams Developer Guide.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#performance_stats_configuration ⇒ Types::PerformanceStatsConfiguration
Configuration settings for sharing the stream session's performance stats with the client
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#protocol ⇒ String
The data transport protocol to use for the stream session.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#role_arn ⇒ String
The ARN of an AWS Identity and Access Management (IAM) role that
Amazon GameLift Streams assumes on your behalf during the stream
session. The role grants Amazon GameLift Streams permission to
obtain temporary credentials for your application. The role's trust
policy must allow the gameliftstreams.amazonaws.com service
principal to assume it. The role name must start with
GameLiftStreams-.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#session_length_seconds ⇒ Integer
The maximum duration of a session. Amazon GameLift Streams will automatically terminate a session after this amount of time has elapsed, regardless of any existing client connections. Default value is 43200 (12 hours).
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#signal_request ⇒ String
A WebRTC ICE offer string to use when initializing a WebRTC connection. Typically, the offer is a very long JSON string. Provide the string as a text value in quotes.
Amazon GameLift Streams also supports setting the field to "NO_CLIENT_CONNECTION". This will create a session without needing any browser request or Web SDK integration. The session starts up as usual and waits for a reconnection from a browser, which is accomplished using CreateStreamSessionConnection.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |
#user_id ⇒ String
An opaque, unique identifier for an end-user, defined by the developer.
3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3178 class StartStreamSessionInput < Struct.new( :client_token, :description, :identifier, :protocol, :signal_request, :application_identifier, :user_id, :locations, :connection_timeout_seconds, :session_length_seconds, :additional_launch_args, :additional_environment_variables, :performance_stats_configuration, :role_arn) SENSITIVE = [:signal_request, :role_arn] include Aws::Structure end |