Class: Aws::GameLiftStreams::Types::StartStreamSessionOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:signal_request, :signal_response]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_environment_variablesHash<String,String>

A set of options that you can use to control the stream session runtime environment, expressed as a set of key-value pairs. You can use this to configure the application or stream session details. You can also provide custom environment variables that Amazon GameLift Streams passes to your game client.

<note markdown=“1”> If you want to debug your application with environment variables, we recommend that you do so in a local environment outside of Amazon GameLift Streams. For more information, refer to the Compatibility Guidance in the troubleshooting section of the Developer Guide.

</note>

‘AdditionalEnvironmentVariables` and `AdditionalLaunchArgs` have similar purposes. `AdditionalEnvironmentVariables` passes data using environment variables; while `AdditionalLaunchArgs` passes data using command-line arguments.

Returns:

  • (Hash<String,String>)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#additional_launch_argsArray<String>

A list of CLI arguments that are sent to the streaming server when a stream session launches. You can use this to configure the application or stream session details. You can also provide custom arguments that Amazon GameLift Streams passes to your game client.

‘AdditionalEnvironmentVariables` and `AdditionalLaunchArgs` have similar purposes. `AdditionalEnvironmentVariables` passes data using environment variables; while `AdditionalLaunchArgs` passes data using command-line arguments.

Returns:

  • (Array<String>)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#application_arnString

An [Amazon Resource Name (ARN)] that uniquely identifies the application resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6`.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#arnString

The [Amazon Resource Name (ARN)] that’s assigned to a stream session resource. When combined with the stream group resource ID, this value uniquely identifies the stream session across all Amazon Web Services Regions. Format is ‘arn:aws:gameliftstreams:[AWS Region]:[AWS account]:streamsession/[stream group resource ID]/[stream session resource ID]`.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#connection_timeout_secondsInteger

The maximum length of time (in seconds) that Amazon GameLift Streams keeps the stream session open. At this point, Amazon GameLift Streams ends the stream session regardless of any existing client connections.

Returns:

  • (Integer)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#created_atTime

A timestamp that indicates when this resource was created. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).

Returns:

  • (Time)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#descriptionString

A human-readable label for the stream session. You can update this value at any time.

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#export_files_metadataTypes::ExportFilesMetadata

Provides details about the stream session’s exported files.



2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#last_updated_atTime

A timestamp that indicates when this resource was last updated. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).

Returns:

  • (Time)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#locationString

The location where Amazon GameLift Streams is streaming your application from.

A location’s name. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, refer to [Regions, quotas, and limitations] in the *Amazon GameLift Streams Developer Guide*.

[1]: docs.aws.amazon.com/gameliftstreams/latest/developerguide/regions-quotas.html

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#log_file_location_uriString

Access location for log files that your content generates during a stream session. These log files are uploaded to cloud storage location at the end of a stream session. The Amazon GameLift Streams application resource defines which log files to upload.

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#protocolString

The data transfer protocol in use with the stream session.

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#session_length_secondsInteger

The length of time that Amazon GameLift Streams keeps the game session open.

Returns:

  • (Integer)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#signal_requestString

The WebRTC ICE offer string that a client generates to initiate a connection to the stream session.

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#signal_responseString

The WebRTC answer string that the stream server generates in response to the ‘SignalRequest`.

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#statusString

The current status of the stream session. A stream session can host clients when in ‘ACTIVE` status.

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#status_reasonString

A short description of the reason the stream session is in ‘ERROR` status.

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#stream_group_idString

The unique identifier for the Amazon GameLift Streams stream group that is hosting the stream session. Format example: ‘sg-1AB2C3De4`.

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#user_idString

An opaque, unique identifier for an end-user, defined by the developer.

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end

#web_sdk_protocol_urlString

The URL of an S3 bucket that stores Amazon GameLift Streams WebSDK files. The URL is used to establish connection with the client.

Returns:

  • (String)


2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2628

class StartStreamSessionOutput < Struct.new(
  :arn,
  :description,
  :stream_group_id,
  :user_id,
  :status,
  :status_reason,
  :protocol,
  :location,
  :signal_request,
  :signal_response,
  :connection_timeout_seconds,
  :session_length_seconds,
  :additional_launch_args,
  :additional_environment_variables,
  :log_file_location_uri,
  :web_sdk_protocol_url,
  :last_updated_at,
  :created_at,
  :application_arn,
  :export_files_metadata)
  SENSITIVE = [:signal_request, :signal_response]
  include Aws::Structure
end