Class: Aws::GameLiftStreams::Types::StreamGroupSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::StreamGroupSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Describes a Amazon GameLift Streams stream group resource for hosting content streams. To retrieve additional stream group details, call [GetStreamGroup].
[1]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_GetStreamGroup.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the stream group resource.
-
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
-
#default_application ⇒ Types::DefaultApplication
Object that identifies the Amazon GameLift Streams application to stream with this stream group.
-
#description ⇒ String
A descriptive label for the stream group.
-
#id ⇒ String
An ID that uniquely identifies the stream group resource.
-
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
-
#status ⇒ String
The current status of the stream group resource.
-
#stream_class ⇒ String
The target stream quality for the stream group.
Instance Attribute Details
#arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the stream group resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2801 class StreamGroupSummary < Struct.new( :arn, :id, :description, :default_application, :stream_class, :status, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
A timestamp that indicates when this resource was created. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2801 class StreamGroupSummary < Struct.new( :arn, :id, :description, :default_application, :stream_class, :status, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#default_application ⇒ Types::DefaultApplication
Object that identifies the Amazon GameLift Streams application to stream with this stream group.
2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2801 class StreamGroupSummary < Struct.new( :arn, :id, :description, :default_application, :stream_class, :status, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A descriptive label for the stream group.
2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2801 class StreamGroupSummary < Struct.new( :arn, :id, :description, :default_application, :stream_class, :status, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
An ID that uniquely identifies the stream group resource. Example ID: ‘sg-1AB2C3De4`.
2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2801 class StreamGroupSummary < Struct.new( :arn, :id, :description, :default_application, :stream_class, :status, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2801 class StreamGroupSummary < Struct.new( :arn, :id, :description, :default_application, :stream_class, :status, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the stream group resource. Possible statuses include the following:
-
‘ACTIVATING`: The stream group is deploying and isn’t ready to host streams.
-
‘ACTIVE`: The stream group is ready to host streams.
-
‘ACTIVE_WITH_ERRORS`: One or more locations in the stream group are in an error state. Verify the details of individual locations and remove any locations which are in error.
-
‘ERROR`: An error occurred when the stream group deployed. See `StatusReason` for more information.
-
‘DELETING`: Amazon GameLift Streams is in the process of deleting the stream group.
-
‘UPDATING_LOCATIONS`: One or more locations in the stream group are in the process of updating (either activating or deleting).
2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2801 class StreamGroupSummary < Struct.new( :arn, :id, :description, :default_application, :stream_class, :status, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#stream_class ⇒ String
The target stream quality for the stream group.
A stream class can be one of the following:
-
gen5n_win2022(NVIDIA, ultra) Supports applications with extremely high 3D scene complexity. Runs applications on Microsoft Windows Server 2022 Base and supports DirectX 12. Compatible with Unreal Engine versions up through 5.4, 32 and 64-bit applications, and anti-cheat technology. Uses NVIDIA A10G Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 24 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
-
gen5n_high(NVIDIA, high) Supports applications with moderate to high 3D scene complexity. Uses NVIDIA A10G Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 4 vCPUs, 16 GB RAM, 12 GB VRAM
-
Tenancy: Supports up to 2 concurrent stream sessions
-
-
gen5n_ultra(NVIDIA, ultra) Supports applications with extremely high 3D scene complexity. Uses dedicated NVIDIA A10G Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 24 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
-
gen4n_win2022(NVIDIA, ultra) Supports applications with extremely high 3D scene complexity. Runs applications on Microsoft Windows Server 2022 Base and supports DirectX 12. Compatible with Unreal Engine versions up through 5.4, 32 and 64-bit applications, and anti-cheat technology. Uses NVIDIA T4 Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 16 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
-
gen4n_high(NVIDIA, high) Supports applications with moderate to high 3D scene complexity. Uses NVIDIA T4 Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 4 vCPUs, 16 GB RAM, 8 GB VRAM
-
Tenancy: Supports up to 2 concurrent stream sessions
-
-
gen4n_ultra(NVIDIA, ultra) Supports applications with high 3D scene complexity. Uses dedicated NVIDIA T4 Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 16 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2801 class StreamGroupSummary < Struct.new( :arn, :id, :description, :default_application, :stream_class, :status, :created_at, :last_updated_at) SENSITIVE = [] include Aws::Structure end |