Class: Aws::GameLiftStreams::Types::UpdateApplicationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_log_output_uriString

An Amazon S3 URI to a bucket where you would like Amazon GameLift Streams to save application logs. Use the following format for the URI: ‘s3://[bucket name]/`. Required if you specify one or more `LogPaths`.

<note markdown=“1”> The log bucket must have permissions that give Amazon GameLift Streams access to write the log files. For more information, see **Getting Started** in the Amazon GameLift Streams Developer Guide.

</note>

Returns:

  • (String)


2929
2930
2931
2932
2933
2934
2935
2936
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2929

class UpdateApplicationInput < Struct.new(
  :application_log_output_uri,
  :application_log_paths,
  :description,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end

#application_log_pathsArray<String>

Locations of log files that your content generates during a stream session. Enter path values that are relative to the ‘ApplicationSourceUri` location. You can specify up to 10 log locations. Amazon GameLift Streams uploads designated log files to the Amazon S3 bucket that you specify in `ApplicationLogOutputUri` at the end of a stream session. To retrieve stored log files, call GetStreamSession and get the `LogFileLocationUri`.

Returns:

  • (Array<String>)


2929
2930
2931
2932
2933
2934
2935
2936
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2929

class UpdateApplicationInput < Struct.new(
  :application_log_output_uri,
  :application_log_paths,
  :description,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A human-readable label for the application.

Returns:

  • (String)


2929
2930
2931
2932
2933
2934
2935
2936
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2929

class UpdateApplicationInput < Struct.new(
  :application_log_output_uri,
  :application_log_paths,
  :description,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

An [Amazon Resource Name (ARN)] or ID that uniquely identifies the application resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:application/9ZY8X7Wv6` or ID-`9ZY8X7Wv6`.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


2929
2930
2931
2932
2933
2934
2935
2936
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2929

class UpdateApplicationInput < Struct.new(
  :application_log_output_uri,
  :application_log_paths,
  :description,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end