Class: Aws::GameLiftStreams::Types::UpdateStreamGroupInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_application_identifierString

The unique identifier of the Amazon GameLift Streams application that you want to set as the default application in a stream group. The application that you specify must be in ‘READY` status. The default application is pre-cached on always-on compute resources, reducing stream startup times. Other applications are automatically cached as needed.

Note that this parameter only sets the default application in a stream group. To associate a new application to an existing stream group, you must use [AssociateApplications].

When you switch default applications in a stream group, it can take up to a few hours for the new default application to be pre-cached.

This value is an [Amazon Resource Name (ARN)] or ID that uniquely identifies the application resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6`. Example ID: `a-9ZY8X7Wv6`.

[1]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_AssociateApplications.html [2]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


4094
4095
4096
4097
4098
4099
4100
4101
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4094

class UpdateStreamGroupInput < Struct.new(
  :identifier,
  :location_configurations,
  :description,
  :default_application_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A descriptive label for the stream group.

Returns:

  • (String)


4094
4095
4096
4097
4098
4099
4100
4101
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4094

class UpdateStreamGroupInput < Struct.new(
  :identifier,
  :location_configurations,
  :description,
  :default_application_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

An [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4`. Example ID: `sg-1AB2C3De4`.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


4094
4095
4096
4097
4098
4099
4100
4101
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4094

class UpdateStreamGroupInput < Struct.new(
  :identifier,
  :location_configurations,
  :description,
  :default_application_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#location_configurationsArray<Types::LocationConfiguration>

A set of one or more locations and the streaming capacity for each location.

Returns:



4094
4095
4096
4097
4098
4099
4100
4101
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4094

class UpdateStreamGroupInput < Struct.new(
  :identifier,
  :location_configurations,
  :description,
  :default_application_identifier)
  SENSITIVE = []
  include Aws::Structure
end