Class: Aws::GameLiftStreams::Types::ValidationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

One or more parameter values in the request fail to satisfy the specified constraints. Correct the invalid parameter values before retrying the request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Description of the error.

Returns:

  • (String)


4441
4442
4443
4444
4445
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4441

class ValidationException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end