Class: Aws::GameLiftStreams::Types::VpcTransitConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Configuration for connecting a stream group location to resources in your Amazon VPC using AWS Transit Gateway. When you specify a VPC transit configuration, Amazon GameLift Streams creates a Transit Gateway and shares it with your account using AWS Resource Access Manager. After the stream group is active, you must complete the setup by accepting the resource share, creating a VPC attachment, and configuring routing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ipv_4_cidr_blocksArray<String>

A list of IPv4 CIDR blocks in your VPC that you want the stream group to be able to access. You can specify up to 5 CIDR blocks. The CIDR blocks must be valid subsets of the VPC’s CIDR blocks and cannot overlap with the service VPC CIDR block.

Returns:

  • (Array<String>)


4471
4472
4473
4474
4475
4476
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4471

class VpcTransitConfiguration < Struct.new(
  :vpc_id,
  :ipv_4_cidr_blocks)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the Amazon VPC that you want to connect to the stream group. The VPC must be in the same Amazon Web Services account as the stream group. This value cannot be changed after the stream group is created.

Returns:

  • (String)


4471
4472
4473
4474
4475
4476
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4471

class VpcTransitConfiguration < Struct.new(
  :vpc_id,
  :ipv_4_cidr_blocks)
  SENSITIVE = []
  include Aws::Structure
end