Class: Aws::GameLiftStreams::Types::VpcTransitConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::VpcTransitConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
The VPC transit configuration details for a stream group location, including the Transit Gateway information needed to complete the VPC attachment setup.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ipv_4_cidr_blocks ⇒ Array<String>
The IPv4 CIDR blocks in your VPC that the stream group can access.
-
#transit_gateway_id ⇒ String
The ID of the Transit Gateway that Amazon GameLift Streams created for this VPC connection.
-
#transit_gateway_resource_share_arn ⇒ String
The ARN of the AWS Resource Access Manager resource share for the Transit Gateway.
-
#vpc_id ⇒ String
The ID of the Amazon VPC that is connected to the stream group.
Instance Attribute Details
#ipv_4_cidr_blocks ⇒ Array<String>
The IPv4 CIDR blocks in your VPC that the stream group can access.
4768 4769 4770 4771 4772 4773 4774 4775 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4768 class VpcTransitConfigurationResponse < Struct.new( :vpc_id, :ipv_4_cidr_blocks, :transit_gateway_id, :transit_gateway_resource_share_arn) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_id ⇒ String
The ID of the Transit Gateway that Amazon GameLift Streams created for this VPC connection. Use this ID when creating your VPC attachment.
4768 4769 4770 4771 4772 4773 4774 4775 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4768 class VpcTransitConfigurationResponse < Struct.new( :vpc_id, :ipv_4_cidr_blocks, :transit_gateway_id, :transit_gateway_resource_share_arn) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_resource_share_arn ⇒ String
The ARN of the AWS Resource Access Manager resource share for the Transit Gateway. You must accept this resource share before you can create a VPC attachment.
4768 4769 4770 4771 4772 4773 4774 4775 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4768 class VpcTransitConfigurationResponse < Struct.new( :vpc_id, :ipv_4_cidr_blocks, :transit_gateway_id, :transit_gateway_resource_share_arn) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the Amazon VPC that is connected to the stream group.
4768 4769 4770 4771 4772 4773 4774 4775 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4768 class VpcTransitConfigurationResponse < Struct.new( :vpc_id, :ipv_4_cidr_blocks, :transit_gateway_id, :transit_gateway_resource_share_arn) SENSITIVE = [] include Aws::Structure end |