Class: Aws::GameLiftStreams::Waiters::ApplicationReady
- Inherits:
-
Object
- Object
- Aws::GameLiftStreams::Waiters::ApplicationReady
- Defined in:
- lib/aws-sdk-gameliftstreams/waiters.rb,
sig/waiters.rbs
Overview
Waits until an application is ready
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ApplicationReady
constructor
A new instance of ApplicationReady.
-
#wait(params = {}) ⇒ Types::GetApplicationOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ApplicationReady
Returns a new instance of ApplicationReady.
125 126 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 125
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
157 158 159 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 157 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetApplicationOutput
Returns a response object which responds to the following methods:
- #arn => String
- #description => String
- #runtime_environment => Types::RuntimeEnvironment
- #executable_path => String
- #application_log_paths => Array<String>
- #application_log_output_uri => String
- #application_source_uri => String
- #id => String
- #status => String
- #status_reason => String
- #replication_statuses => Array<Types::ReplicationStatus>
- #created_at => Time
- #last_updated_at => Time
- #associated_stream_groups => Array<String>
152 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 152
def wait: (
|