Class: Aws::GameLiftStreams::Waiters::StreamGroupActive
- Inherits:
-
Object
- Object
- Aws::GameLiftStreams::Waiters::StreamGroupActive
- Defined in:
- lib/aws-sdk-gameliftstreams/waiters.rb
Overview
Waits until a stream group is active
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ StreamGroupActive
constructor
A new instance of StreamGroupActive.
-
#wait(params = {}) ⇒ Types::GetStreamGroupOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ StreamGroupActive
Returns a new instance of StreamGroupActive.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 170 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 120, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_stream_group, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "ACTIVE" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "ERROR" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "ACTIVE_WITH_ERRORS" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "DELETING" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
214 215 216 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 214 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetStreamGroupOutput
Returns a response object which responds to the following methods:
-
#arn => String
-
#description => String
-
#default_application => Types::DefaultApplication
-
#location_states => Array<Types::LocationState>
-
#stream_class => String
-
#id => String
-
#status => String
-
#status_reason => String
-
#last_updated_at => Time
-
#created_at => Time
-
#expires_at => Time
-
#associated_applications => Array<String>
209 210 211 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 209 def wait(params = {}) @waiter.wait(client: @client, params: params) end |