Class: Aws::GameLiftStreams::Waiters::StreamGroupDeleted
- Inherits:
-
Object
- Object
- Aws::GameLiftStreams::Waiters::StreamGroupDeleted
- Defined in:
- lib/aws-sdk-gameliftstreams/waiters.rb,
sig/waiters.rbs
Overview
Waits until a stream group is deleted
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ StreamGroupDeleted
constructor
A new instance of StreamGroupDeleted.
-
#wait(params = {}) ⇒ Types::GetStreamGroupOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ StreamGroupDeleted
Returns a new instance of StreamGroupDeleted.
227 228 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 227
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
250 251 252 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 250 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetStreamGroupOutput
Returns a response object which responds to the following methods:
- #arn => String
- #description => String
- #default_application => Types::DefaultApplication
- #location_states => Array<Types::LocationState>
- #stream_class => String
- #id => String
- #status => String
- #status_reason => String
- #last_updated_at => Time
- #created_at => Time
- #expires_at => Time
- #associated_applications => Array<String>
245 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 245
def wait: (
|