Class: Aws::GameLiftStreams::Waiters::StreamSessionActive
- Inherits:
-
Object
- Object
- Aws::GameLiftStreams::Waiters::StreamSessionActive
- Defined in:
- lib/aws-sdk-gameliftstreams/waiters.rb,
sig/waiters.rbs
Overview
Waits until a stream session is active
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ StreamSessionActive
constructor
A new instance of StreamSessionActive.
-
#wait(params = {}) ⇒ Types::GetStreamSessionOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ StreamSessionActive
Returns a new instance of StreamSessionActive.
263 264 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 263
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
295 296 297 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 295 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetStreamSessionOutput
Returns a response object which responds to the following methods:
- #arn => String
- #description => String
- #stream_group_id => String
- #user_id => String
- #status => String
- #status_reason => String
- #protocol => String
- #location => String
- #signal_request => String
- #signal_response => String
- #connection_timeout_seconds => Integer
- #session_length_seconds => Integer
- #additional_launch_args => Array<String>
- #additional_environment_variables => Hash<String,String>
- #performance_stats_configuration => Types::PerformanceStatsConfiguration
- #log_file_location_uri => String
- #web_sdk_protocol_url => String
- #last_updated_at => Time
- #created_at => Time
- #application_arn => String
- #export_files_metadata => Types::ExportFilesMetadata
290 |
# File 'lib/aws-sdk-gameliftstreams/waiters.rb', line 290
def wait: (
|