Class: Aws::GameLiftStreams::Types::AddStreamGroupLocationsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identifierString

A stream group to add the specified locations to.

This value is a Amazon Resource Name (ARN) that uniquely identifies the stream group resource. Format example: ‘sg-1AB2C3De4`.

Returns:

  • (String)


43
44
45
46
47
48
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 43

class AddStreamGroupLocationsInput < Struct.new(
  :identifier,
  :location_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#location_configurationsArray<Types::LocationConfiguration>

A set of one or more locations and the streaming capacity for each location.

Returns:



43
44
45
46
47
48
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 43

class AddStreamGroupLocationsInput < Struct.new(
  :identifier,
  :location_configurations)
  SENSITIVE = []
  include Aws::Structure
end