Class: Aws::GameLiftStreams::Types::CreateApplicationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::CreateApplicationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_log_output_uri ⇒ String
An Amazon S3 URI to a bucket where you would like Amazon GameLift Streams to save application logs.
-
#application_log_paths ⇒ Array<String>
Locations of log files that your content generates during a stream session.
-
#application_source_uri ⇒ String
The location of the content that you want to stream.
-
#client_token ⇒ String
A unique identifier that represents a client request.
-
#description ⇒ String
A human-readable label for the application.
-
#executable_path ⇒ String
The path and file name of the executable file that launches the content for streaming.
-
#runtime_environment ⇒ Types::RuntimeEnvironment
A set of configuration settings to run the application on a stream group.
-
#tags ⇒ Hash<String,String>
A list of labels to assign to the new application resource.
Instance Attribute Details
#application_log_output_uri ⇒ String
An Amazon S3 URI to a bucket where you would like Amazon GameLift Streams to save application logs. Use the following format for the URI: ‘s3://[bucket name]/`. Required if you specify one or more `LogPaths`.
<note markdown=“1”> The log bucket must have permissions that give Amazon GameLift Streams access to write the log files. For more information, see **Getting Started** in the Amazon GameLift Streams Developer Guide.
</note>
369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 369 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#application_log_paths ⇒ Array<String>
Locations of log files that your content generates during a stream session. Enter path values that are relative to the ‘ApplicationSourceUri` location. You can specify up to 10 log locations. Amazon GameLift Streams uploads designated log files to the Amazon S3 bucket that you specify in `ApplicationLogOutputUri` at the end of a stream session. To retrieve stored log files, call GetStreamSession and get the `LogFileLocationUri`.
369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 369 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#application_source_uri ⇒ String
The location of the content that you want to stream. Enter the URI of an Amazon S3 location (bucket name and prefixes) that contains your content. Use the following format for the URI: ‘s3://[bucket name]/`. The location can have a multi-level prefix structure, but it must include all the files needed to run the content. Amazon GameLift Streams copies everything under the specified location.
This value is immutable. To designate a different content location, create a new application.
<note markdown=“1”> The S3 bucket and the Amazon GameLift Streams application must be in the same Amazon Web Services Region.
</note>
369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 369 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique identifier that represents a client request. The request is idempotent, which ensures that an API request completes only once. When users send a request, Amazon GameLift Streams automatically populates this field.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 369 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A human-readable label for the application. You can update this value later.
369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 369 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#executable_path ⇒ String
The path and file name of the executable file that launches the content for streaming. Enter a path value that is relative to the location set in ‘ApplicationSourceUri`.
369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 369 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#runtime_environment ⇒ Types::RuntimeEnvironment
A set of configuration settings to run the application on a stream group. This configures the operating system, and can include compatibility layers and other drivers.
A runtime environment can be one of the following:
-
For Linux applications
-
Ubuntu 22.04 LTS(‘Type=UBUNTU, Version=22_04_LTS`)
^
-
-
For Windows applications
-
Microsoft Windows Server 2022 Base (‘Type=WINDOWS, Version=2022`)
-
Proton 8.0-5 (‘Type=PROTON, Version=20241007`)
-
Proton 8.0-2c (‘Type=PROTON, Version=20230704`)
-
369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 369 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of labels to assign to the new application resource. Tags are developer-defined key-value pairs. Tagging Amazon Web Services resources is useful for resource management, access management and cost allocation. See [ Tagging Amazon Web Services Resources] in the *Amazon Web Services General Reference*. You can use TagResource to add tags, UntagResource to remove tags, and ListTagsForResource to view tags on existing resources. The maximum tag limit might be lower than stated. See the *Amazon Web Services General Reference* for actual tagging limits.
369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 369 class CreateApplicationInput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :client_token, :description, :executable_path, :runtime_environment, :tags) SENSITIVE = [] include Aws::Structure end |