Class: Aws::GameLiftStreams::Types::CreateStreamGroupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::CreateStreamGroupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique identifier that represents a client request.
-
#default_application_identifier ⇒ String
The unique identifier of the Amazon GameLift Streams application that you want to associate to a stream group as the default application.
-
#description ⇒ String
A descriptive label for the stream group.
-
#location_configurations ⇒ Array<Types::LocationConfiguration>
A set of one or more locations and the streaming capacity for each location.
-
#stream_class ⇒ String
The target stream quality for sessions that are hosted in this stream group.
-
#tags ⇒ Hash<String,String>
A list of labels to assign to the new stream group resource.
Instance Attribute Details
#client_token ⇒ String
A unique identifier that represents a client request. The request is idempotent, which ensures that an API request completes only once. When users send a request, Amazon GameLift Streams automatically populates this field.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
650 651 652 653 654 655 656 657 658 659 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 650 class CreateStreamGroupInput < Struct.new( :client_token, :default_application_identifier, :description, :location_configurations, :stream_class, :tags) SENSITIVE = [] include Aws::Structure end |
#default_application_identifier ⇒ String
The unique identifier of the Amazon GameLift Streams application that you want to associate to a stream group as the default application. The application must be in ‘READY` status. By setting the default application identifier, you will optimize startup performance of this application in your stream group. Once set, this application cannot be disassociated from the stream group, unlike applications that are associated using AssociateApplications. If not set when creating a stream group, you will need to call AssociateApplications later, before you can start streaming.
650 651 652 653 654 655 656 657 658 659 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 650 class CreateStreamGroupInput < Struct.new( :client_token, :default_application_identifier, :description, :location_configurations, :stream_class, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A descriptive label for the stream group.
650 651 652 653 654 655 656 657 658 659 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 650 class CreateStreamGroupInput < Struct.new( :client_token, :default_application_identifier, :description, :location_configurations, :stream_class, :tags) SENSITIVE = [] include Aws::Structure end |
#location_configurations ⇒ Array<Types::LocationConfiguration>
A set of one or more locations and the streaming capacity for each location.
650 651 652 653 654 655 656 657 658 659 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 650 class CreateStreamGroupInput < Struct.new( :client_token, :default_application_identifier, :description, :location_configurations, :stream_class, :tags) SENSITIVE = [] include Aws::Structure end |
#stream_class ⇒ String
The target stream quality for sessions that are hosted in this stream group. Set a stream class that is appropriate to the type of content that you’re streaming. Stream class determines the type of computing resources Amazon GameLift Streams uses and impacts the cost of streaming. The following options are available:
A stream class can be one of the following:
-
gen5n_win2022(NVIDIA, ultra) Supports applications with extremely high 3D scene complexity. Runs applications on Microsoft Windows Server 2022 Base and supports DirectX 12. Compatible with most Unreal Engine 5.x builds, 32-bit applications, and anti-cheat technology. Uses NVIDIA A10G Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 24 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
-
gen5n_high(NVIDIA, high) Supports applications with moderate to high 3D scene complexity. Uses NVIDIA A10G Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 4 vCPUs, 16 GB RAM, 12 GB VRAM
-
Tenancy: Supports up to 2 concurrent stream sessions
-
-
gen5n_ultra(NVIDIA, ultra) Supports applications with extremely high 3D scene complexity. Uses dedicated NVIDIA A10G Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 24 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
-
gen4n_win2022(NVIDIA, ultra) Supports applications with extremely high 3D scene complexity. Runs applications on Microsoft Windows Server 2022 Base and supports DirectX 12. Compatible with most Unreal Engine 5.2 and 5.3 builds, 32-bit applications, and anti-cheat technology. Uses NVIDIA T4 Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 16 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
-
gen4n_high(NVIDIA, high) Supports applications with moderate to high 3D scene complexity. Uses NVIDIA T4 Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 4 vCPUs, 16 GB RAM, 8 GB VRAM
-
Tenancy: Supports up to 2 concurrent stream sessions
-
-
gen4n_ultra(NVIDIA, ultra) Supports applications with high 3D scene complexity. Uses dedicated NVIDIA T4 Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 16 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
650 651 652 653 654 655 656 657 658 659 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 650 class CreateStreamGroupInput < Struct.new( :client_token, :default_application_identifier, :description, :location_configurations, :stream_class, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of labels to assign to the new stream group resource. Tags are developer-defined key-value pairs. It is useful to tag Amazon Web Services resources for resource management, access management, and cost allocation. See [ Tagging Amazon Web Services Resources] in the *Amazon Web Services General Reference*. You can use TagResource, UntagResource, and ListTagsForResource to add, remove, and view tags on existing resources. The maximum tag limit might be lower than stated. See the Amazon Web Services for actual tagging limits.
650 651 652 653 654 655 656 657 658 659 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 650 class CreateStreamGroupInput < Struct.new( :client_token, :default_application_identifier, :description, :location_configurations, :stream_class, :tags) SENSITIVE = [] include Aws::Structure end |