Class: Aws::GameLiftStreams::Types::CreateStreamSessionConnectionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:signal_request]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique identifier that represents a client request. The request is idempotent, which ensures that an API request completes only once. When users send a request, Amazon GameLift Streams automatically populates this field.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


920
921
922
923
924
925
926
927
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 920

class CreateStreamSessionConnectionInput < Struct.new(
  :client_token,
  :identifier,
  :signal_request,
  :stream_session_identifier)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#identifierString

Amazon Resource Name (ARN)][1

or ID that uniquely identifies the

stream group resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/sg-1AB2C3De4` or ID-`sg-1AB2C3De4`.

The stream group that you want to run this stream session with. The stream group must be in ‘ACTIVE` status and have idle stream capacity.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


920
921
922
923
924
925
926
927
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 920

class CreateStreamSessionConnectionInput < Struct.new(
  :client_token,
  :identifier,
  :signal_request,
  :stream_session_identifier)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#signal_requestString

A WebRTC ICE offer string to use when initializing a WebRTC connection. The offer is a very long JSON string. Provide the string as a text value in quotes. The offer must be newly generated, not the same offer provided to ‘StartStreamSession`.

Returns:

  • (String)


920
921
922
923
924
925
926
927
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 920

class CreateStreamSessionConnectionInput < Struct.new(
  :client_token,
  :identifier,
  :signal_request,
  :stream_session_identifier)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#stream_session_identifierString

Amazon Resource Name (ARN)][1

that uniquely identifies the stream

session resource. Format example: ‘1AB2C3De4`. The stream session must be in `PENDING_CLIENT_RECONNECTION` or `ACTIVE` status.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


920
921
922
923
924
925
926
927
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 920

class CreateStreamSessionConnectionInput < Struct.new(
  :client_token,
  :identifier,
  :signal_request,
  :stream_session_identifier)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end