Class: Aws::GameLiftStreams::Types::ExportStreamSessionFilesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identifierString

An [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/1AB2C3De4` or ID-`1AB2C3De4`.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1146

class ExportStreamSessionFilesInput < Struct.new(
  :identifier,
  :output_uri,
  :stream_session_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#output_uriString

The S3 bucket URI where Amazon GameLift Streams uploads the set of compressed exported files for this stream session. Amazon GameLift Streams generates a ZIP file name based on the stream session metadata. Alternatively, you can provide a custom file name with a ‘.zip` file extension.

Example 1: If you provide an S3 URI called ‘s3://MyBucket/MyGame_Session1.zip`, then Amazon GameLift Streams will save the files at that location.

Example 2: If you provide an S3 URI called ‘s3://MyBucket/MyGameSessions_ExportedFiles/`, then Amazon GameLift Streams will save the files at `s3://MyBucket/MyGameSessions_ExportedFiles/YYYYMMDD-HHMMSS-appId-sg-Id-sessionId.zip` or another similar name.

Returns:

  • (String)


1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1146

class ExportStreamSessionFilesInput < Struct.new(
  :identifier,
  :output_uri,
  :stream_session_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#stream_session_identifierString

An [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream session resource. Format example: ‘1AB2C3De4`.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


1146
1147
1148
1149
1150
1151
1152
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1146

class ExportStreamSessionFilesInput < Struct.new(
  :identifier,
  :output_uri,
  :stream_session_identifier)
  SENSITIVE = []
  include Aws::Structure
end