Class: Aws::GameLiftStreams::Types::GetApplicationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::GetApplicationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_log_output_uri ⇒ String
An Amazon S3 URI to a bucket where you would like Amazon GameLift Streams to save application logs.
-
#application_log_paths ⇒ Array<String>
Locations of log files that your content generates during a stream session.
-
#application_source_uri ⇒ String
The original Amazon S3 location of uploaded stream content for the application.
-
#arn ⇒ String
An Amazon Resource Name (ARN) that’s assigned to an application resource and uniquely identifies it across all Amazon Web Services Regions.
-
#associated_stream_groups ⇒ Array<String>
A set of stream groups that this application is associated with.
-
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
-
#description ⇒ String
A human-readable label for the application.
-
#executable_path ⇒ String
The path and file name of the executable file that launches the content for streaming.
-
#id ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the application resource.
-
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
-
#replication_statuses ⇒ Array<Types::ReplicationStatus>
A set of replication statuses for each location.
-
#runtime_environment ⇒ Types::RuntimeEnvironment
Configuration settings that identify the operating system for an application resource.
-
#status ⇒ String
The current status of the application resource.
-
#status_reason ⇒ String
A short description of the status reason when the application is in ‘ERROR` status.
Instance Attribute Details
#application_log_output_uri ⇒ String
An Amazon S3 URI to a bucket where you would like Amazon GameLift Streams to save application logs. Required if you specify one or more ‘ApplicationLogPaths`.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#application_log_paths ⇒ Array<String>
Locations of log files that your content generates during a stream session. Amazon GameLift Streams uploads log files to the Amazon S3 bucket that you specify in ‘ApplicationLogOutputUri` at the end of a stream session. To retrieve stored log files, call
- GetStreamSession][1
-
and get the ‘LogFileLocationUri`.
[1]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_GetStreamSession.html
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#application_source_uri ⇒ String
The original Amazon S3 location of uploaded stream content for the application.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
An Amazon Resource Name (ARN) that’s assigned to an application resource and uniquely identifies it across all Amazon Web Services Regions. Format is ‘arn:aws:gameliftstreams:[AWS Region]:[AWS account]:application/[resource ID]`.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#associated_stream_groups ⇒ Array<String>
A set of stream groups that this application is associated with. You can use any of these stream groups to stream your application.
This value is a set of [Amazon Resource Names (ARNs)] that uniquely identify stream group resources. Format example: ‘arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/sg-1AB2C3De4`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
A timestamp that indicates when this resource was created. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A human-readable label for the application. You can edit this value.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#executable_path ⇒ String
The path and file name of the executable file that launches the content for streaming.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the application resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:application/a-9ZY8X7Wv6` or ID-`a-9ZY8X7Wv6`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#replication_statuses ⇒ Array<Types::ReplicationStatus>
A set of replication statuses for each location.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#runtime_environment ⇒ Types::RuntimeEnvironment
Configuration settings that identify the operating system for an application resource. This can also include a compatibility layer and other drivers.
A runtime environment can be one of the following:
-
For Linux applications
-
Ubuntu 22.04 LTS (‘Type=UBUNTU, Version=22_04_LTS`)
^
-
-
For Windows applications
-
Microsoft Windows Server 2022 Base (‘Type=WINDOWS, Version=2022`)
-
Proton 8.0-5 (‘Type=PROTON, Version=20241007`)
-
Proton 8.0-2c (‘Type=PROTON, Version=20230704`)
-
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the application resource. Possible statuses include the following:
-
‘INITIALIZED`: Amazon GameLift Streams has received the request and is initiating the work flow to create an application.
-
‘PROCESSING`: The create application work flow is in process. Amazon GameLift Streams is copying the content and caching for future deployment in a stream group.
-
‘READY`: The application is ready to deploy in a stream group.
-
‘ERROR`: An error occurred when setting up the application. See `StatusReason` for more information.
-
‘DELETING`: Amazon GameLift Streams is in the process of deleting the application.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
A short description of the status reason when the application is in ‘ERROR` status.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 1311 class GetApplicationOutput < Struct.new( :application_log_output_uri, :application_log_paths, :application_source_uri, :arn, :associated_stream_groups, :created_at, :description, :executable_path, :id, :last_updated_at, :replication_statuses, :runtime_environment, :status, :status_reason) SENSITIVE = [] include Aws::Structure end |