Class: Aws::GameLiftStreams::Types::LocationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::LocationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Configuration settings that define a stream group’s stream capacity for a location. When configuring a location for the first time, you must specify a numeric value for at least one of the two capacity types. To update the capacity for an existing stream group, call UpdateStreamGroup. To add a new location and specify its capacity, call AddStreamGroupLocations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#always_on_capacity ⇒ Integer
The streaming capacity that is allocated and ready to handle stream requests without delay.
-
#location_name ⇒ String
A location’s name.
-
#on_demand_capacity ⇒ Integer
The streaming capacity that Amazon GameLift Streams can allocate in response to stream requests, and then de-allocate when the session has terminated.
Instance Attribute Details
#always_on_capacity ⇒ Integer
The streaming capacity that is allocated and ready to handle stream requests without delay. You pay for this capacity whether it’s in use or not. Best for quickest time from streaming request to streaming session.
2026 2027 2028 2029 2030 2031 2032 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2026 class LocationConfiguration < Struct.new( :always_on_capacity, :location_name, :on_demand_capacity) SENSITIVE = [] include Aws::Structure end |
#location_name ⇒ String
A location’s name. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, see the Regions and quotas section in the Amazon GameLift Streams Developer Guide .
2026 2027 2028 2029 2030 2031 2032 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2026 class LocationConfiguration < Struct.new( :always_on_capacity, :location_name, :on_demand_capacity) SENSITIVE = [] include Aws::Structure end |
#on_demand_capacity ⇒ Integer
The streaming capacity that Amazon GameLift Streams can allocate in response to stream requests, and then de-allocate when the session has terminated. This offers a cost control measure at the expense of a greater startup time (typically under 5 minutes).
2026 2027 2028 2029 2030 2031 2032 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2026 class LocationConfiguration < Struct.new( :always_on_capacity, :location_name, :on_demand_capacity) SENSITIVE = [] include Aws::Structure end |