Class: Aws::GameLiftStreams::Types::PerformanceStatsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::PerformanceStatsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Configuration settings for sharing the stream session’s performance stats with the client
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#shared_with_client ⇒ Boolean
Performance stats for the session are streamed to the client when set to ‘true`.
Instance Attribute Details
#shared_with_client ⇒ Boolean
Performance stats for the session are streamed to the client when set to ‘true`. Defaults to `false`.
2732 2733 2734 2735 2736 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2732 class PerformanceStatsConfiguration < Struct.new( :shared_with_client) SENSITIVE = [] include Aws::Structure end |