Class: Aws::GameLiftStreams::Types::RemoveStreamGroupLocationsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identifierString

A stream group to remove the specified locations from.

This value is a Amazon Resource Name (ARN) that uniquely identifies the stream group resource. Format example: ‘sg-1AB2C3De4`.

Returns:

  • (String)


2162
2163
2164
2165
2166
2167
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2162

class RemoveStreamGroupLocationsInput < Struct.new(
  :identifier,
  :locations)
  SENSITIVE = []
  include Aws::Structure
end

#locationsArray<String>

A set of locations to remove this stream group.

A set of location names. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, refer to

Regions and quotas][1

in the *Amazon GameLift Streams Developer

Guide*.

[1]: docs.aws.amazon.com/gameliftstreams/latest/developerguide/regions-quotas.html

Returns:

  • (Array<String>)


2162
2163
2164
2165
2166
2167
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2162

class RemoveStreamGroupLocationsInput < Struct.new(
  :identifier,
  :locations)
  SENSITIVE = []
  include Aws::Structure
end