Class: Aws::GameLiftStreams::Types::RemoveStreamGroupLocationsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::RemoveStreamGroupLocationsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
A stream group to remove the specified locations from.
-
#locations ⇒ Array<String>
A set of locations to remove this stream group.
Instance Attribute Details
#identifier ⇒ String
A stream group to remove the specified locations from.
This value is a Amazon Resource Name (ARN) that uniquely identifies the stream group resource. Format example: ‘sg-1AB2C3De4`.
2162 2163 2164 2165 2166 2167 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2162 class RemoveStreamGroupLocationsInput < Struct.new( :identifier, :locations) SENSITIVE = [] include Aws::Structure end |
#locations ⇒ Array<String>
A set of locations to remove this stream group.
A set of location names. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, refer to
- Regions and quotas][1
-
in the *Amazon GameLift Streams Developer
Guide*.
[1]: docs.aws.amazon.com/gameliftstreams/latest/developerguide/regions-quotas.html
2162 2163 2164 2165 2166 2167 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2162 class RemoveStreamGroupLocationsInput < Struct.new( :identifier, :locations) SENSITIVE = [] include Aws::Structure end |