Class: Aws::GameLiftStreams::Types::RemoveStreamGroupLocationsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identifierString

A stream group to remove the specified locations from.

This value is a Amazon Resource Name (ARN) that uniquely identifies the stream group resource. Format example: ‘1AB2C3De4`. </p>

Returns:

  • (String)


2132
2133
2134
2135
2136
2137
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2132

class RemoveStreamGroupLocationsInput < Struct.new(
  :identifier,
  :locations)
  SENSITIVE = []
  include Aws::Structure
end

#locationsArray<String>

A set of locations to remove this stream group.

A set of location names. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, see the Regions and quotas section in the Amazon GameLift Streams Developer Guide . </p>

Returns:

  • (Array<String>)


2132
2133
2134
2135
2136
2137
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2132

class RemoveStreamGroupLocationsInput < Struct.new(
  :identifier,
  :locations)
  SENSITIVE = []
  include Aws::Structure
end