Class: Aws::GameLiftStreams::Types::ReplicationStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::ReplicationStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Represents the status of the replication of an application to a location. An application cannot be streamed from a location until it has finished replicating there.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#location ⇒ String
A location’s name.
-
#status ⇒ String
The current status of the replication process.
Instance Attribute Details
#location ⇒ String
A location’s name. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, refer to [Regions, quotas, and limitations] in the *Amazon GameLift Streams Developer Guide*.
[1]: docs.aws.amazon.com/gameliftstreams/latest/developerguide/regions-quotas.html
2794 2795 2796 2797 2798 2799 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2794 class ReplicationStatus < Struct.new( :location, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the replication process.
2794 2795 2796 2797 2798 2799 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2794 class ReplicationStatus < Struct.new( :location, :status) SENSITIVE = [] include Aws::Structure end |