Class: Aws::GameLiftStreams::Types::ReplicationStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::ReplicationStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Represents the status of the replication of an application to a location. An application cannot be streamed from a location until it has finished replicating there.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#location ⇒ String
A location’s name.
-
#status ⇒ String
The current status of the replication process.
Instance Attribute Details
#location ⇒ String
A location’s name. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, see the Regions and quotas section in the Amazon GameLift Streams Developer Guide .
2155 2156 2157 2158 2159 2160 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2155 class ReplicationStatus < Struct.new( :location, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the replication process.
2155 2156 2157 2158 2159 2160 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2155 class ReplicationStatus < Struct.new( :location, :status) SENSITIVE = [] include Aws::Structure end |