Class: Aws::GameLiftStreams::Types::RevokeStreamUrlInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::RevokeStreamUrlInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
An [Amazon Resource Name (ARN)][1] or ID that uniquely identifies the stream group resource.
-
#revocation_mode ⇒ String
Controls what happens to running stream sessions when you revoke the stream URL.
-
#stream_url_identifier ⇒ String
The unique identifier of the stream URL to revoke.
Instance Attribute Details
#identifier ⇒ String
An Amazon Resource Name (ARN) or ID that uniquely identifies
the stream group resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4.
Example ID: sg-1AB2C3De4.
This is the stream group that owns the stream URL.
3724 3725 3726 3727 3728 3729 3730 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3724 class RevokeStreamUrlInput < Struct.new( :identifier, :stream_url_identifier, :revocation_mode) SENSITIVE = [] include Aws::Structure end |
#revocation_mode ⇒ String
Controls what happens to running stream sessions when you revoke the
stream URL. If you do not specify a value, the default is
REVOKE_URL. Possible values include the following:
-
REVOKE_URL: Stops the stream URL from starting new stream sessions. Running sessions continue until they end. -
REVOKE_AND_TERMINATE_SESSIONS: Stops new stream sessions and ends any running stream sessions.
3724 3725 3726 3727 3728 3729 3730 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3724 class RevokeStreamUrlInput < Struct.new( :identifier, :stream_url_identifier, :revocation_mode) SENSITIVE = [] include Aws::Structure end |
#stream_url_identifier ⇒ String
The unique identifier of the stream URL to revoke. Specify a stream
URL ID or Amazon Resource Name (ARN). Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamurl/sg-1AB2C3De4/su-1AB2C3De4.
Example ID: su-1AB2C3De4.
3724 3725 3726 3727 3728 3729 3730 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3724 class RevokeStreamUrlInput < Struct.new( :identifier, :stream_url_identifier, :revocation_mode) SENSITIVE = [] include Aws::Structure end |