Class: Aws::GameLiftStreams::Types::ShaderCacheSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::ShaderCacheSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Describes a shader cache associated with an Amazon GameLift Streams application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arn ⇒ String
An [Amazon Resource Name (ARN)][1] that uniquely identifies the application resource.
-
#associated_stream_groups ⇒ Array<String>
The stream groups compatible with this shader cache.
-
#identifier ⇒ String
A unique identifier for the shader cache, formatted as a 32-character hexadecimal string.
-
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
-
#status ⇒ String
The current status of the shader cache.
-
#storage_bytes ⇒ Integer
The total storage used by all compiled shader files in this shader cache, in bytes.
Instance Attribute Details
#application_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies the
application resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6.
3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856 class ShaderCacheSummary < Struct.new( :identifier, :application_arn, :status, :last_updated_at, :storage_bytes, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#associated_stream_groups ⇒ Array<String>
The stream groups compatible with this shader cache. Compatibility is based on GPU type and GPU driver version. For more information on shader cache compatibility, see Shader caches in the Amazon GameLift Streams Developer Guide.
This value is a set of Amazon Resource Names (ARNs) that
uniquely identify stream group resources. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4.
3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856 class ShaderCacheSummary < Struct.new( :identifier, :application_arn, :status, :last_updated_at, :storage_bytes, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
A unique identifier for the shader cache, formatted as a
32-character hexadecimal string. Format is
1271e693c50b940e228582f1ccdd4e27.
3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856 class ShaderCacheSummary < Struct.new( :identifier, :application_arn, :status, :last_updated_at, :storage_bytes, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
Timestamps are expressed using in ISO8601 format, such as:
2022-12-27T22:29:40+00:00 (UTC).
3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856 class ShaderCacheSummary < Struct.new( :identifier, :application_arn, :status, :last_updated_at, :storage_bytes, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the shader cache. Possible statuses include the following:
-
INITIALIZED: Amazon GameLift Streams received the request and is preparing the shader cache. -
PROCESSING: Amazon GameLift Streams is replicating the shader cache to the streaming locations in the associated stream groups. -
READY: The shader cache is replicated and available for use in stream sessions. -
DELETING: Amazon GameLift Streams is deleting the shader cache. -
ERROR: An error occurred during shader cache processing. Create a new shader cache to try again.
3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856 class ShaderCacheSummary < Struct.new( :identifier, :application_arn, :status, :last_updated_at, :storage_bytes, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |
#storage_bytes ⇒ Integer
The total storage used by all compiled shader files in this shader cache, in bytes.
3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3856 class ShaderCacheSummary < Struct.new( :identifier, :application_arn, :status, :last_updated_at, :storage_bytes, :associated_stream_groups) SENSITIVE = [] include Aws::Structure end |