Class: Aws::GameLiftStreams::Types::StartStreamSessionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:signal_request]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_environment_variablesHash<String,String>

A set of options that you can use to control the stream session runtime environment, expressed as a set of key-value pairs. You can use this to configure the application or stream session details. You can also provide custom environment variables that Amazon GameLift Streams passes to your game client.

<note markdown=“1”> If you want to debug your application with environment variables, we recommend that you do so in a local environment outside of Amazon GameLift Streams. For more information, refer to the Compatibility Guidance in the troubleshooting section of the Developer Guide.

</note>

‘AdditionalEnvironmentVariables` and `AdditionalLaunchArgs` have similar purposes. `AdditionalEnvironmentVariables` passes data using environment variables; while `AdditionalLaunchArgs` passes data using command-line arguments.

Returns:

  • (Hash<String,String>)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#additional_launch_argsArray<String>

A list of CLI arguments that are sent to the streaming server when a stream session launches. You can use this to configure the application or stream session details. You can also provide custom arguments that Amazon GameLift Streams passes to your game client.

‘AdditionalEnvironmentVariables` and `AdditionalLaunchArgs` have similar purposes. `AdditionalEnvironmentVariables` passes data using environment variables; while `AdditionalLaunchArgs` passes data using command-line arguments.

Returns:

  • (Array<String>)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#application_identifierString

An [Amazon Resource Name (ARN)] or ID that uniquely identifies the application resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:application/9ZY8X7Wv6` or ID-`9ZY8X7Wv6`.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#client_tokenString

A unique identifier that represents a client request. The request is idempotent, which ensures that an API request completes only once. When users send a request, Amazon GameLift Streams automatically populates this field.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#connection_timeout_secondsInteger

Length of time (in seconds) that Amazon GameLift Streams should wait for a client to connect to the stream session. This time span starts when the stream session reaches ‘ACTIVE` status. If no client connects before the timeout, Amazon GameLift Streams stops the stream session with status of `TERMINATED`. Default value is 120.

Returns:

  • (Integer)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#descriptionString

A human-readable label for the stream session. You can update this value later.

Returns:

  • (String)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#identifierString

The stream group to run this stream session with.

This value is an [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/1AB2C3De4` or ID-`1AB2C3De4`.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html

Returns:

  • (String)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#locationsArray<String>

A list of locations, in order of priority, where you want Amazon GameLift Streams to start a stream from. Amazon GameLift Streams selects the location with the next available capacity to start a single stream session in. If this value is empty, Amazon GameLift Streams attempts to start a stream session in the primary location.

This value is A set of location names. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, see the Regions and quotas section in the Amazon GameLift Streams Developer Guide . </p>

Returns:

  • (Array<String>)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#protocolString

The data transport protocol to use for the stream session.

Returns:

  • (String)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#session_length_secondsInteger

The maximum length of time (in seconds) that Amazon GameLift Streams keeps the stream session open. At this point, Amazon GameLift Streams ends the stream session regardless of any existing client connections. Default value is 43200.

Returns:

  • (Integer)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#signal_requestString

A WebRTC ICE offer string to use when initializing a WebRTC connection. The offer is a very long JSON string. Provide the string as a text value in quotes.

Returns:

  • (String)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end

#user_idString

An opaque, unique identifier for an end-user, defined by the developer.

Returns:

  • (String)


2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2346

class StartStreamSessionInput < Struct.new(
  :additional_environment_variables,
  :additional_launch_args,
  :application_identifier,
  :client_token,
  :connection_timeout_seconds,
  :description,
  :identifier,
  :locations,
  :protocol,
  :session_length_seconds,
  :signal_request,
  :user_id)
  SENSITIVE = [:signal_request]
  include Aws::Structure
end