Class: Aws::GameLiftStreams::Types::StartStreamSessionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::StartStreamSessionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:signal_request, :signal_response]
Instance Attribute Summary collapse
-
#additional_environment_variables ⇒ Hash<String,String>
A set of options that you can use to control the stream session runtime environment, expressed as a set of key-value pairs.
-
#additional_launch_args ⇒ Array<String>
A list of CLI arguments that are sent to the streaming server when a stream session launches.
-
#application_arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the application resource.
-
#arn ⇒ String
The Amazon Resource Name (ARN) assigned to the stream session resource.
-
#connection_timeout_seconds ⇒ Integer
The maximum length of time (in seconds) that Amazon GameLift Streams keeps the stream session open.
-
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
-
#description ⇒ String
A human-readable label for the stream session.
-
#export_files_metadata ⇒ Types::ExportFilesMetadata
Provides details about the stream session’s exported files.
-
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
-
#location ⇒ String
The location where Amazon GameLift Streams is streaming your application from.
-
#log_file_location_uri ⇒ String
Access location for log files that your content generates during a stream session.
-
#protocol ⇒ String
The data transfer protocol in use with the stream session.
-
#session_length_seconds ⇒ Integer
The length of time that Amazon GameLift Streams keeps the game session open.
-
#signal_request ⇒ String
The WebRTC ICE offer string that a client generates to initiate a connection to the stream session.
-
#signal_response ⇒ String
The WebRTC answer string that the stream server generates in response to the ‘SignalRequest`.
-
#status ⇒ String
The current status of the stream session.
-
#status_reason ⇒ String
A short description of the reason the stream session is in ‘ERROR` status.
-
#stream_group_id ⇒ String
The unique identifier for the Amazon GameLift Streams stream group that is hosting the stream session.
-
#user_id ⇒ String
An opaque, unique identifier for an end-user, defined by the developer.
-
#web_sdk_protocol_url ⇒ String
The URL of an S3 bucket that stores Amazon GameLift Streams WebSDK files.
Instance Attribute Details
#additional_environment_variables ⇒ Hash<String,String>
A set of options that you can use to control the stream session runtime environment, expressed as a set of key-value pairs. You can use this to configure the application or stream session details. You can also provide custom environment variables that Amazon GameLift Streams passes to your game client.
<note markdown=“1”> If you want to debug your application with environment variables, we recommend that you do so in a local environment outside of Amazon GameLift Streams. For more information, refer to the Compatibility Guidance in the troubleshooting section of the Developer Guide.
</note>
‘AdditionalEnvironmentVariables` and `AdditionalLaunchArgs` have similar purposes. `AdditionalEnvironmentVariables` passes data using environment variables; while `AdditionalLaunchArgs` passes data using command-line arguments.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#additional_launch_args ⇒ Array<String>
A list of CLI arguments that are sent to the streaming server when a stream session launches. You can use this to configure the application or stream session details. You can also provide custom arguments that Amazon GameLift Streams passes to your game client.
‘AdditionalEnvironmentVariables` and `AdditionalLaunchArgs` have similar purposes. `AdditionalEnvironmentVariables` passes data using environment variables; while `AdditionalLaunchArgs` passes data using command-line arguments.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#application_arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the application resource. Format example: ‘arn:aws:gameliftstreams:us-west-2:123456789012:application/9ZY8X7Wv6`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) assigned to the stream session resource. When combined with the stream group ARN, this value uniquely identifies it across all Amazon Web Services Regions. Format is ‘arn:aws:gameliftstreams:[AWS Region]:[AWS account]:streamsession/[resource ID]`.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#connection_timeout_seconds ⇒ Integer
The maximum length of time (in seconds) that Amazon GameLift Streams keeps the stream session open. At this point, Amazon GameLift Streams ends the stream session regardless of any existing client connections.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#created_at ⇒ Time
A timestamp that indicates when this resource was created. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#description ⇒ String
A human-readable label for the stream session. You can update this value at any time.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#export_files_metadata ⇒ Types::ExportFilesMetadata
Provides details about the stream session’s exported files.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#location ⇒ String
The location where Amazon GameLift Streams is streaming your application from.
A location’s name. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, see the Regions and quotas section in the Amazon GameLift Streams Developer Guide .
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#log_file_location_uri ⇒ String
Access location for log files that your content generates during a stream session. These log files are uploaded to cloud storage location at the end of a stream session. The Amazon GameLift Streams application resource defines which log files to upload.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#protocol ⇒ String
The data transfer protocol in use with the stream session.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#session_length_seconds ⇒ Integer
The length of time that Amazon GameLift Streams keeps the game session open.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#signal_request ⇒ String
The WebRTC ICE offer string that a client generates to initiate a connection to the stream session.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#signal_response ⇒ String
The WebRTC answer string that the stream server generates in response to the ‘SignalRequest`.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#status ⇒ String
The current status of the stream session. A stream session can host clients when in ‘ACTIVE` status.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#status_reason ⇒ String
A short description of the reason the stream session is in ‘ERROR` status.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#stream_group_id ⇒ String
The unique identifier for the Amazon GameLift Streams stream group that is hosting the stream session.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#user_id ⇒ String
An opaque, unique identifier for an end-user, defined by the developer.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |
#web_sdk_protocol_url ⇒ String
The URL of an S3 bucket that stores Amazon GameLift Streams WebSDK files. The URL is used to establish connection with the client.
2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2503 class StartStreamSessionOutput < Struct.new( :additional_environment_variables, :additional_launch_args, :application_arn, :arn, :connection_timeout_seconds, :created_at, :description, :export_files_metadata, :last_updated_at, :location, :log_file_location_uri, :protocol, :session_length_seconds, :signal_request, :signal_response, :status, :status_reason, :stream_group_id, :user_id, :web_sdk_protocol_url) SENSITIVE = [:signal_request, :signal_response] include Aws::Structure end |