Class: Aws::GameLiftStreams::Types::StreamGroupSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::StreamGroupSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Describes a Amazon GameLift Streams stream group resource for hosting content streams. To retrieve additional stream group details, call GetStreamGroup.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource.
-
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
-
#default_application ⇒ Types::DefaultApplication
Object that identifies the Amazon GameLift Streams application to stream with this stream group.
-
#description ⇒ String
A descriptive label for the stream group.
-
#id ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource.
-
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
-
#status ⇒ String
The current status of the stream group resource.
-
#stream_class ⇒ String
The target stream quality for the stream group.
Instance Attribute Details
#arn ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/1AB2C3De4` or ID-`1AB2C3De4`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2679 class StreamGroupSummary < Struct.new( :arn, :created_at, :default_application, :description, :id, :last_updated_at, :status, :stream_class) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
A timestamp that indicates when this resource was created. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2679 class StreamGroupSummary < Struct.new( :arn, :created_at, :default_application, :description, :id, :last_updated_at, :status, :stream_class) SENSITIVE = [] include Aws::Structure end |
#default_application ⇒ Types::DefaultApplication
Object that identifies the Amazon GameLift Streams application to stream with this stream group.
2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2679 class StreamGroupSummary < Struct.new( :arn, :created_at, :default_application, :description, :id, :last_updated_at, :status, :stream_class) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A descriptive label for the stream group.
2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2679 class StreamGroupSummary < Struct.new( :arn, :created_at, :default_application, :description, :id, :last_updated_at, :status, :stream_class) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource. Format example: ARN-‘arn:aws:gameliftstreams:us-west-2:123456789012:streamgroup/1AB2C3De4` or ID-`1AB2C3De4`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2679 class StreamGroupSummary < Struct.new( :arn, :created_at, :default_application, :description, :id, :last_updated_at, :status, :stream_class) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2679 class StreamGroupSummary < Struct.new( :arn, :created_at, :default_application, :description, :id, :last_updated_at, :status, :stream_class) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the stream group resource. Possible statuses include the following:
-
‘ACTIVATING`: The stream group is deploying and isn’t ready to host streams.
-
‘ACTIVE`: The stream group is ready to host streams.
-
‘ACTIVE_WITH_ERRORS`: One or more locations in the stream group are in an error state. Verify the details of individual locations and remove any locations which are in error.
-
‘ERROR`: An error occurred when the stream group deployed. See `StatusReason` for more information.
-
‘DELETING`: Amazon GameLift Streams is in the process of deleting the stream group.
-
‘UPDATING_LOCATIONS`: One or more locations in the stream group are in the process of updating (either activating or deleting).
2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2679 class StreamGroupSummary < Struct.new( :arn, :created_at, :default_application, :description, :id, :last_updated_at, :status, :stream_class) SENSITIVE = [] include Aws::Structure end |
#stream_class ⇒ String
The target stream quality for the stream group.
A stream class can be one of the following:
-
gen5n_win2022(NVIDIA, ultra) Supports applications with extremely high 3D scene complexity. Runs applications on Microsoft Windows Server 2022 Base and supports DirectX 12. Compatible with most Unreal Engine 5.x builds, 32-bit applications, and anti-cheat technology. Uses NVIDIA A10G Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 24 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
-
gen5n_high(NVIDIA, high) Supports applications with moderate to high 3D scene complexity. Uses NVIDIA A10G Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 4 vCPUs, 16 GB RAM, 12 GB VRAM
-
Tenancy: Supports up to 2 concurrent stream sessions
-
-
gen5n_ultra(NVIDIA, ultra) Supports applications with extremely high 3D scene complexity. Uses dedicated NVIDIA A10G Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 24 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
-
gen4n_win2022(NVIDIA, ultra) Supports applications with extremely high 3D scene complexity. Runs applications on Microsoft Windows Server 2022 Base and supports DirectX 12. Compatible with most Unreal Engine 5.2 and 5.3 builds, 32-bit applications, and anti-cheat technology. Uses NVIDIA T4 Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 16 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
-
gen4n_high(NVIDIA, high) Supports applications with moderate to high 3D scene complexity. Uses NVIDIA T4 Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 4 vCPUs, 16 GB RAM, 8 GB VRAM
-
Tenancy: Supports up to 2 concurrent stream sessions
-
-
gen4n_ultra(NVIDIA, ultra) Supports applications with high 3D scene complexity. Uses dedicated NVIDIA T4 Tensor GPU.-
Reference resolution: 1080p
-
Reference frame rate: 60 fps
-
Workload specifications: 8 vCPUs, 32 GB RAM, 16 GB VRAM
-
Tenancy: Supports 1 concurrent stream session
-
2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2679 class StreamGroupSummary < Struct.new( :arn, :created_at, :default_application, :description, :id, :last_updated_at, :status, :stream_class) SENSITIVE = [] include Aws::Structure end |