Class: Aws::GameLiftStreams::Types::StreamSessionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::StreamSessionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Describes an Amazon GameLift Streams stream session. To retrieve additional details for the stream session, call [GetStreamSession].
[1]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_GetStreamSession.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the application resource.
-
#arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the stream session resource.
-
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
-
#export_files_metadata ⇒ Types::ExportFilesMetadata
Provides details about the stream session’s exported files.
-
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
-
#location ⇒ String
The location where Amazon GameLift Streams hosts and streams your application.
-
#protocol ⇒ String
The data transfer protocol in use with the stream session.
-
#status ⇒ String
The current status of the stream session resource.
-
#status_reason ⇒ String
A short description of the reason the stream session is in ‘ERROR` status or `TERMINATED` status.
-
#user_id ⇒ String
An opaque, unique identifier for an end-user, defined by the developer.
Instance Attribute Details
#application_arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the application resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3723 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :status_reason, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the stream session resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:streamsession/sg-1AB2C3De4/ABC123def4567`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3723 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :status_reason, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
A timestamp that indicates when this resource was created. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3723 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :status_reason, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#export_files_metadata ⇒ Types::ExportFilesMetadata
Provides details about the stream session’s exported files.
3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3723 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :status_reason, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3723 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :status_reason, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location where Amazon GameLift Streams hosts and streams your application. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, refer to [Regions, quotas, and limitations] in the *Amazon GameLift Streams Developer Guide*.
[1]: docs.aws.amazon.com/gameliftstreams/latest/developerguide/regions-quotas.html
3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3723 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :status_reason, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The data transfer protocol in use with the stream session.
3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3723 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :status_reason, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the stream session resource.
-
‘ACTIVATING`: The stream session is starting and preparing to stream.
-
‘ACTIVE`: The stream session is ready and waiting for a client connection. A client has `ConnectionTimeoutSeconds` (specified in `StartStreamSession`) from when the session reaches `ACTIVE` state to establish a connection. If no client connects within this timeframe, the session automatically terminates.
-
‘CONNECTED`: The stream session has a connected client. A session will automatically terminate if there is no user input for 60 minutes, or if the maximum length of a session specified by `SessionLengthSeconds` in `StartStreamSession` is exceeded.
-
‘ERROR`: The stream session failed to activate. See `StatusReason` (returned by `GetStreamSession` and `StartStreamSession`) for more information.
-
‘PENDING_CLIENT_RECONNECTION`: A client has recently disconnected and the stream session is waiting for the client to reconnect. A client has `ConnectionTimeoutSeconds` (specified in `StartStreamSession`) from when the session reaches `PENDING_CLIENT_RECONNECTION` state to re-establish a connection. If no client connects within this timeframe, the session automatically terminates.
-
‘RECONNECTING`: A client has initiated a reconnect to a session that was in `PENDING_CLIENT_RECONNECTION` state.
-
‘TERMINATING`: The stream session is ending.
-
‘TERMINATED`: The stream session has ended.
3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3723 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :status_reason, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
A short description of the reason the stream session is in ‘ERROR` status or `TERMINATED` status.
‘ERROR` status reasons:
-
‘applicationLogS3DestinationError`: Could not write the application log to the Amazon S3 bucket that is configured for the streaming application. Make sure the bucket still exists.
-
‘internalError`: An internal service error occurred. Start a new stream session to continue streaming.
-
‘invalidSignalRequest`: The WebRTC signal request that was sent is not valid. When starting or reconnecting to a stream session, use `generateSignalRequest` in the Amazon GameLift Streams Web SDK to generate a new signal request.
-
‘placementTimeout`: Amazon GameLift Streams could not find available stream capacity to start a stream session. Increase the stream capacity in the stream group or wait until capacity becomes available.
‘TERMINATED` status reasons:
-
‘apiTerminated`: The stream session was terminated by an API call to [TerminateStreamSession].
-
‘applicationExit`: The streaming application exited or crashed. The stream session was terminated because the application is no longer running.
-
‘connectionTimeout`: The stream session was terminated because the client failed to connect within the connection timeout period specified by `ConnectionTimeoutSeconds`.
-
‘maxSessionLengthTimeout`: The stream session was terminated because it exceeded the maximum session length timeout period specified by `SessionLengthSeconds`.
-
‘reconnectionTimeout`: The stream session was terminated because the client failed to reconnect within the reconnection timeout period specified by `ConnectionTimeoutSeconds` after losing connection.
[1]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_TerminateStreamSession.html
3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3723 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :status_reason, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
An opaque, unique identifier for an end-user, defined by the developer.
3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3723 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :status_reason, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |