Class: Aws::GameLiftStreams::Types::StreamSessionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::StreamSessionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Describes a Amazon GameLift Streams stream session. To retrieve additional details for the stream session, call [GetStreamSession].
[1]: docs.aws.amazon.com/gameliftstreams/latest/apireference/API_GetStreamSession.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the application resource.
-
#arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the stream session resource.
-
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
-
#export_files_metadata ⇒ Types::ExportFilesMetadata
Provides details about the stream session’s exported files.
-
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated.
-
#location ⇒ String
The location where Amazon GameLift Streams is hosting the stream session.
-
#protocol ⇒ String
The data transfer protocol in use with the stream session.
-
#status ⇒ String
The current status of the stream session resource.
-
#user_id ⇒ String
An opaque, unique identifier for an end-user, defined by the developer.
Instance Attribute Details
#application_arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the application resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2906 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
An [Amazon Resource Name (ARN)] that uniquely identifies the stream session resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:streamsession/sg-1AB2C3De4/ABC123def4567`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2906 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
A timestamp that indicates when this resource was created. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2906 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#export_files_metadata ⇒ Types::ExportFilesMetadata
Provides details about the stream session’s exported files.
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2906 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
A timestamp that indicates when this resource was last updated. Timestamps are expressed using in ISO8601 format, such as: ‘2022-12-27T22:29:40+00:00` (UTC).
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2906 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The location where Amazon GameLift Streams is hosting the stream session.
A location’s name. For example, ‘us-east-1`. For a complete list of locations that Amazon GameLift Streams supports, refer to [Regions, quotas, and limitations] in the *Amazon GameLift Streams Developer Guide*.
[1]: docs.aws.amazon.com/gameliftstreams/latest/developerguide/regions-quotas.html
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2906 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The data transfer protocol in use with the stream session.
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2906 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the stream session resource. Possible statuses include the following:
-
‘ACTIVATING`: The stream session is starting and preparing to stream.
-
‘ACTIVE`: The stream session is ready to accept client connections.
-
‘CONNECTED`: The stream session has a connected client.
-
‘PENDING_CLIENT_RECONNECTION`: A client has recently disconnected, and the stream session is waiting for the client to reconnect. After a short time, if the client doesn’t reconnect, the stream session status transitions to ‘TERMINATED`.
-
‘TERMINATING`: The stream session is ending.
-
‘TERMINATED`: The stream session has ended.
-
‘ERROR`: The stream session failed to activate.
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2906 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |
#user_id ⇒ String
An opaque, unique identifier for an end-user, defined by the developer.
2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 2906 class StreamSessionSummary < Struct.new( :arn, :user_id, :status, :protocol, :last_updated_at, :created_at, :application_arn, :export_files_metadata, :location) SENSITIVE = [] include Aws::Structure end |