Class: Aws::GameLiftStreams::Types::StreamUrlSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::StreamUrlSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Describes a stream URL. This is a summary view that omits the full configuration, such as launch arguments and display settings. To retrieve the complete configuration, call GetStreamUrl.
Constant Summary collapse
- SENSITIVE =
[:stream_url]
Instance Attribute Summary collapse
-
#application_arn ⇒ String
The application that runs in the stream sessions.
-
#arn ⇒ String
The [Amazon Resource Name (ARN)][1] that uniquely identifies the stream URL across all Amazon Web Services Regions.
-
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
-
#description ⇒ String
The descriptive label for the stream URL.
-
#expires_at ⇒ Time
The date and time when the stream URL expires and stops accepting new stream sessions.
-
#remaining_uses ⇒ Integer
The number of times the stream URL can still be used to start a stream session.
-
#session_length_seconds ⇒ Integer
The maximum length of time, in seconds, that a stream session started from this stream URL can run.
-
#status ⇒ String
The current status of the stream URL.
-
#status_reason ⇒ String
Additional information about why the stream URL is in its current status.
-
#stream_group_arn ⇒ String
The stream group that runs the stream sessions.
-
#stream_url ⇒ String
The shareable stream URL.
-
#stream_url_id ⇒ String
The unique identifier for the stream URL resource, for example
su-1AB2C3De4. -
#usage_limit ⇒ Integer
The maximum number of times the stream URL can start a stream session.
Instance Attribute Details
#application_arn ⇒ String
The application that runs in the stream sessions.
This value is an Amazon Resource Name (ARN) that uniquely
identifies the application resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:application/a-9ZY8X7Wv6.
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the
stream URL across all Amazon Web Services Regions. Format is
arn:aws:gameliftstreams:[AWS Region]:[AWS account]:streamurl/[stream group resource ID]/[stream URL resource ID].
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#created_at ⇒ Time
A timestamp that indicates when this resource was created.
Timestamps are expressed using in ISO8601 format, such as:
2022-12-27T22:29:40+00:00 (UTC).
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#description ⇒ String
The descriptive label for the stream URL.
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#expires_at ⇒ Time
The date and time when the stream URL expires and stops accepting
new stream sessions. Timestamps are expressed using in ISO8601
format, such as: 2022-12-27T22:29:40+00:00 (UTC).
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#remaining_uses ⇒ Integer
The number of times the stream URL can still be used to start a stream session.
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#session_length_seconds ⇒ Integer
The maximum length of time, in seconds, that a stream session started from this stream URL can run.
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#status ⇒ String
The current status of the stream URL. Possible statuses include the following:
-
ACTIVE: The stream URL is valid and can start stream sessions. -
EXPIRED: The stream URL has passed its expiration time and can no longer start stream sessions. -
REVOKED: The stream URL was revoked and can no longer start stream sessions. -
LIMIT_REACHED: The stream URL has been used the maximum number of times and can no longer start stream sessions.
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#status_reason ⇒ String
Additional information about why the stream URL is in its current
status. Amazon GameLift Streams populates this value when the status
is REVOKED. Possible values include the following:
-
userRevoked: You revoked the stream URL. -
revokedAndTerminatingSessions: You revoked the stream URL and Amazon GameLift Streams is ending its running stream sessions. -
revokedAndSessionsTerminated: You revoked the stream URL and its running stream sessions have ended. -
streamGroupDeleted: The stream group was deleted, which revoked the stream URL. -
applicationDeleted: The application was deleted, which revoked the stream URL.
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#stream_group_arn ⇒ String
The stream group that runs the stream sessions.
This value is an Amazon Resource Name (ARN) that uniquely
identifies the stream group resource. Example ARN:
arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4.
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#stream_url ⇒ String
The shareable stream URL. Distribute this URL to end users so that they can start and play a stream session in a hosted web player. Treat the stream URL as a secret. Anyone who has it can start a stream session until the stream URL expires, is revoked, or reaches its usage limit.
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#stream_url_id ⇒ String
The unique identifier for the stream URL resource, for example
su-1AB2C3De4.
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |
#usage_limit ⇒ Integer
The maximum number of times the stream URL can start a stream session.
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 4953 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4937 class StreamUrlSummary < Struct.new( :arn, :stream_url_id, :stream_url, :status, :status_reason, :expires_at, :created_at, :usage_limit, :remaining_uses, :stream_group_arn, :application_arn, :session_length_seconds, :description) SENSITIVE = [:stream_url] include Aws::Structure end |