Class: Aws::GameLiftStreams::Types::UpdateStreamGroupInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::GameLiftStreams::Types::UpdateStreamGroupInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-gameliftstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A descriptive label for the stream group.
-
#identifier ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource.
-
#location_configurations ⇒ Array<Types::LocationConfiguration>
A set of one or more locations and the streaming capacity for each location.
Instance Attribute Details
#description ⇒ String
A descriptive label for the stream group.
3237 3238 3239 3240 3241 3242 3243 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3237 class UpdateStreamGroupInput < Struct.new( :description, :identifier, :location_configurations) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
An [Amazon Resource Name (ARN)] or ID that uniquely identifies the stream group resource. Example ARN: ‘arn:aws:gameliftstreams:us-west-2:111122223333:streamgroup/sg-1AB2C3De4`. Example ID: `sg-1AB2C3De4`.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html
3237 3238 3239 3240 3241 3242 3243 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3237 class UpdateStreamGroupInput < Struct.new( :description, :identifier, :location_configurations) SENSITIVE = [] include Aws::Structure end |
#location_configurations ⇒ Array<Types::LocationConfiguration>
A set of one or more locations and the streaming capacity for each location.
3237 3238 3239 3240 3241 3242 3243 |
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 3237 class UpdateStreamGroupInput < Struct.new( :description, :identifier, :location_configurations) SENSITIVE = [] include Aws::Structure end |