Class: Aws::GameLiftStreams::Types::VpcTransitConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-gameliftstreams/types.rb

Overview

The VPC transit configuration details for a stream group location, including the Transit Gateway information needed to complete the VPC attachment setup.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ipv_4_cidr_blocksArray<String>

The IPv4 CIDR blocks in your VPC that the stream group can access.

Returns:

  • (Array<String>)


4504
4505
4506
4507
4508
4509
4510
4511
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4504

class VpcTransitConfigurationResponse < Struct.new(
  :vpc_id,
  :ipv_4_cidr_blocks,
  :transit_gateway_id,
  :transit_gateway_resource_share_arn)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_idString

The ID of the Transit Gateway that Amazon GameLift Streams created for this VPC connection. Use this ID when creating your VPC attachment.

Returns:

  • (String)


4504
4505
4506
4507
4508
4509
4510
4511
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4504

class VpcTransitConfigurationResponse < Struct.new(
  :vpc_id,
  :ipv_4_cidr_blocks,
  :transit_gateway_id,
  :transit_gateway_resource_share_arn)
  SENSITIVE = []
  include Aws::Structure
end

#transit_gateway_resource_share_arnString

The ARN of the AWS Resource Access Manager resource share for the Transit Gateway. You must accept this resource share before you can create a VPC attachment.

Returns:

  • (String)


4504
4505
4506
4507
4508
4509
4510
4511
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4504

class VpcTransitConfigurationResponse < Struct.new(
  :vpc_id,
  :ipv_4_cidr_blocks,
  :transit_gateway_id,
  :transit_gateway_resource_share_arn)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the Amazon VPC that is connected to the stream group.

Returns:

  • (String)


4504
4505
4506
4507
4508
4509
4510
4511
# File 'lib/aws-sdk-gameliftstreams/types.rb', line 4504

class VpcTransitConfigurationResponse < Struct.new(
  :vpc_id,
  :ipv_4_cidr_blocks,
  :transit_gateway_id,
  :transit_gateway_resource_share_arn)
  SENSITIVE = []
  include Aws::Structure
end